function [xyzw,xyzwc,momerr] = cub_sphtri(n,P1,P2,P3,pos)

%--------------------------------------------------------------------------
% Object:
% The routine computes a cubature formula "xyzw" with (numerical) algebraic 
% degree of precision "n" on the spherical triangle with vertices "P1",  
% "P2", "P3", by a 2D formula of degree of precision "m+n" on the xy  
% projection of the spherical triangle rotated to put the barycenter at the
% north pole.
%
% Next it determines a cubature formula "xyzwc" with algebraic degree of 
% precision "n" with at most "(n+1)^2" nodes on the spherical triangle with 
% vertices "P1", "P2", "P3", by a 2D formula of degree of precision "m+n"
% on the xy projection of the spherical triangle rotated so to put its
% barycenter at the north pole. 
%
% The parameter "m" depends on the size of the circumradius and it is "2" 
% for "small" "r", becoming bigger as "r" approaches "1".
%--------------------------------------------------------------------------
% Input: 
% n: algebraic degree of precision of the rule;
% P1,P2,P3: column arrays of the spherical triangle vertices coords
% pos: positive weights for pos=1, possible neg weights (faster) for pos=0
%--------------------------------------------------------------------------
% Output:
% xywz : 4-column array of nodes cartesian coords and weights
% xywzc: 4-column array of nodes cartesian coords and weights (compressed
%        rule).
%--------------------------------------------------------------------------
% Routines called:
% 1. compute_m (attached)
% 2. gqcircsect (external)
% 3. dCATCH (external)
%--------------------------------------------------------------------------
% Data:
% The original routine has been written by M. Vianello on May 2019.
% Last Update: 01/01/2021 by A. Sommariva.
%-------------------------------------------------------------------------

% ............................ troubleshooting ............................

if size(P1,1) == 1, P1=P1'; end
if size(P2,1) == 1, P2=P2'; end
if size(P3,1) == 1, P3=P3'; end




% ------------------------------- main code -------------------------------

% ... barycenter ...
CC=1/3*(P1+P2+P3); CC=CC/norm(CC);

% .................... rotation matrix to the north pole ..................

[az,el,r] = cart2sph(CC(1),CC(2),CC(3));
phi=az; theta=pi/2-el;
cp=cos(phi); sp=sin(phi); ct=cos(theta); st=sin(theta);
R1=[ct 0 -st; 0 1 0; st 0 ct]; R2=[cp sp 0; -sp cp 0; 0 0 1]; 
R=R1*R2; invR=R';

% ............... vertices of the triangle at the North Pole ..............

A=R*P1; B=R*P2; C=R*P3; vert=[A B C A];


% ...... computing "m" needed in determining the degree of precision ......

% Using normalization factor RR on the projections A,B,C.
% In other words, we make up a cubature rule on the unit sphere (by
% contraction w.r.t. the unit sphere and map back the so obtained rule to
% the starting sphere with radius R).
RR=norm(P1); m=compute_m(A/RR,B/RR,C/RR);

% .................... determining quadrature rule ........................  

xyzw=[]; % nodes on the sphere
nodV=[]; % nodes on the xy-plane

for i=1:3
    
    % affine transformation matrix 
    P=vert(:,i); Q=vert(:,i+1);
    om=acos(P'*Q);
    xi=cos(om/2); eta=sin(om/2);
    M=[xi eta 0 0; 0 0 xi eta; xi -eta 0 0; 0 0 xi -eta];
    h=[P(1); P(2); Q(1); Q(2)];
    u=M\h;
    T=[u(1) u(2); u(3) u(4)];
    
    % nodes and weights for the xy-projection of the rotated spher.triangle
    nw=gqcircsect(m+n,om/2,0,1); nod2=T*nw(:,1:2)';
    
    % spherical triangle nodes and weights on North Pole spher.triangle
    x=nod2(1,:); y=nod2(2,:); z=sqrt(1-x.^2-y.^2); 
    
    weights=abs(det(T))*nw(:,3)./z';
    
    % inverse rotation to original spherical triangle
    nodes=invR*[x; y; z];
  
    
    XX=(nodes(:,1))'; YY=(nodes(:,2))'; ZZ=zeros(size(XX));
    
    % cubature rule update
    xyzw=[xyzw;[nodes' weights]];
    
end

% Exporting results to the sphere with radius "R".
X=RR*xyzw(:,1); Y=RR*xyzw(:,2); Z=RR*xyzw(:,3); W=RR*xyzw(:,4);
xyzw=[X Y Z W];

% Tchakaloff compression (if required)
if nargout > 1
    % [pts,w,momerr] = comprexcub3(n,xyzw(:,1:3),xyzw(:,4),pos);
    [pts,w,momerr]  = dCATCHsph(n,xyzw(:,1:3),xyzw(:,4));
    xyzwc=[pts w];
    
    % Exporting results to the sphere with radius "R".
    Xc=RR*xyzwc(:,1); Yc=RR*xyzwc(:,2); Zc=RR*xyzwc(:,3); Wc=RR*xyzwc(:,4);
    xyzwc=[Xc Yc Zc Wc];
end









function T=chebpolys(deg,x)

%--------------------------------------------------------------------------
% Object:
% computes the Chebyshev-Vandermonde matrix on the real line by recurrence
%--------------------------------------------------------------------------
% Input:
% deg = maximum polynomial degree
% x = 1-column array of abscissas
%--------------------------------------------------------------------------
% Output:
% T: Chebyshev-Vandermonde matrix at x, T(i,j+1)=T_j(x_i), j=0,...,deg
%--------------------------------------------------------------------------

% inizialization
T=zeros(length(x),deg+1);
t0=ones(length(x),1);
T(:,1)=t0;
t1=x;
T(:,2)=t1;

% 3-term recurrence
for j=2:deg
    t2=2*x.*t1-t0;
    T(:,j+1)=t2;
    t0=t1;
    t1=t2;
end









function m=compute_m(P1,P2,P3)

%--------------------------------------------------------------------------
% Object:
% It computes the "m" positive integer value depending from the sph. tri.
% twith vertices P1, P2, P3, so that a cubature rule over the sph. triangle 
% with ADE equal to "n" can be obtained via cubature of degree "m+n" on  
% its projection on the xy-plane.
%--------------------------------------------------------------------------
% Input:
% P1, P2, P3: points defining the sph. triangle.
%--------------------------------------------------------------------------
% Output:
% m: positive integer value depending from the sph .triangle with vertices 
% P1, P2, P3, so that a cubature rule over the sph. triangle with ADE 
% equal to "n" can be obtained via cubature of degree "m+n" on its 
% projection on the xy-plane.
%--------------------------------------------------------------------------
%% Data:
%% The original routine has been written by M. Vianello on May 2019.
%% Last Update: 30/12/2020 by A. Sommariva.
%%-------------------------------------------------------------------------

r(1)=(norm(P1(1:2)))^2; 
r(2)=(norm(P2(1:2)))^2; 
r(3)=(norm(P3(1:2)))^2;
r=max(r);

% fprintf('\n \t rho: %1.15e',r)

deg_tabs=degree_table;
if r > 9.99999999769741521050e-01
    ii=131072;
else
    ii=min(find(r <= deg_tabs(:,1)));
    m=deg_tabs(ii,2);
end










function deg_tabs=degree_table

%--------------------------------------------------------------------------
% Object:
% Table with value "rho" in the first column and value "m" on the second
% column.
% "m" is a positive integer value depending from the sph .triangle with  
% vertices P1, P2, P3, so that a cubature rule over the sph. triangle with  
% ADE equal to "n" can be obtained via cubature of degree "m+n" on its 
% projection on the xy-plane.
%--------------------------------------------------------------------------
% Input:
% deg_tabs: is a matrix where the first column has as components value "rho"
% while the second one are positive integer values depending from the 
% sph .triangle with vertices  P1, P2, P3, so that a cubature rule over the
% sph. triangle with ADE equal to "n" can be obtained via cubature of 
%  degree "m+n" on its projection on the xy-plane.
%--------------------------------------------------------------------------
%% Data:
%% The original routine has been written by M. Vianello on May 2019.
%% Last Update: 30/12/2020 by A. Sommariva.
%%-------------------------------------------------------------------------

deg_tabs=[1.00000000000000002092e-08        2
 1.00773068209446168056e-08        2
 1.01552112763456918726e-08        2
 1.02337179863251926791e-08        2
 1.03128316067218470257e-08        2
 1.03925568293671320563e-08        2
 1.04728983823635957191e-08        2
 1.05538610303652296344e-08        2
 1.06354495748601117478e-08        2
 1.07176688544550342151e-08        2
 1.08005237451625400385e-08        2
 1.08840191606900541230e-08        2
 1.09681600527313800705e-08        2
 1.10529514112602219111e-08        2
 1.11383982648262055746e-08        2
 1.12245056808530593033e-08        2
 1.13112787659392143954e-08        2
 1.13987226661605251852e-08        2
 1.14868425673755483196e-08        2
 1.15756436955330355706e-08        2
 1.16651313169819611288e-08        2
 1.17553107387836995664e-08        2
 1.18461873090268474701e-08        2
 1.19377664171443578700e-08        2
 1.20300534942332422376e-08        2
 1.21230540133765290332e-08        2
 1.22167734899679304411e-08        2
 1.23112174820388963497e-08        2
 1.24063915905883186168e-08        2
 1.25023014599145597136e-08        2
 1.25989527779502838560e-08        2
 1.26963512765997283189e-08        2
 1.27945027320787342246e-08        2
 1.28934129652571579580e-08        2
 1.29930878420041710953e-08        2
 1.30935332735360948148e-08        2
 1.31947552167670599569e-08        2
 1.32967596746621271184e-08        2
 1.33995526965933978325e-08        2
 1.35031403786987214416e-08        2
 1.36075288642433318437e-08        2
 1.37127243439840087934e-08        2
 1.38187330565363361687e-08        2
 1.39255612887446187943e-08        2
 1.40332153760548466001e-08        2
 1.41417017028902395817e-08        2
 1.42510267030299922967e-08        2
 1.43611968599907728715e-08        2
 1.44722187074113437887e-08        2
 1.45840988294398627387e-08        2
 1.46968438611244739962e-08        2
 1.48104604888067386811e-08        2
 1.49249554505182910226e-08        2
 1.50403355363802507902e-08        2
 1.51566075890060437085e-08        2
 1.52737785039071236210e-08        2
 1.53918552299020530083e-08        2
 1.55108447695284058453e-08        2
 1.56307541794581743966e-08        2
 1.57515905709162134183e-08        2
 1.58733611101020857270e-08        2
 1.59960730186148790011e-08        2
 1.61197335738815860769e-08        2
 1.62443501095886549996e-08        2
 1.63699300161170198518e-08        2
 1.64964807409802053840e-08        2
 1.66240097892661341059e-08        2
 1.67525247240821362213e-08        2
 1.68820331670036289358e-08        2
 1.70125427985258927290e-08        2
 1.71440613585197188316e-08        2
 1.72765966466903455731e-08        2
 1.74101565230401534379e-08        2
 1.75447489083345960519e-08        2
 1.76803817845720850927e-08        2
 1.78170631954572898012e-08        2
 1.79548012468783043897e-08        2
 1.80936041073871638769e-08        2
 1.82334800086844230351e-08        2
 1.83744372461072491990e-08        2
 1.85164841791215417912e-08        2
 1.86596292318174598312e-08        2
 1.88038808934091680651e-08        2
 1.89492477187381962212e-08        2
 1.90957383287809672552e-08        2
 1.92433614111597997538e-08        2
 1.93921257206583076315e-08        2
 1.95420400797405122123e-08        2
 1.96931133790742192565e-08        2
 1.98453545780580322720e-08        2
 1.99987727053528689976e-08        2
 2.01533768594173524003e-08        2
 2.03091762090473475012e-08        2
 2.04661799939198988031e-08        2
 2.06243975251409264263e-08        2
 2.07838381857975511470e-08        2
 2.09445114315146876884e-08        2
 2.11064267910155489205e-08        2
 2.12695938666869212389e-08        2
 2.14340223351485890811e-08        2
 2.15997219478271699691e-08        2
 2.17667025315345916911e-08        2
 2.19349739890505995057e-08        2
 2.21045462997101933436e-08        2
 2.22754295199955648709e-08        2
 2.24476337841322366308e-08        2
 2.26211693046902635300e-08        2
 2.27960463731898216917e-08        2
 2.29722753607115122371e-08        2
 2.31498667185116082993e-08        2
 2.33288309786415835236e-08        2
 2.35091787545728418793e-08        2
 2.36909207418263212198e-08        2
 2.38740677186064709742e-08        2
 2.40586305464406693780e-08        2
 2.42446201708233060025e-08        2
 2.44320476218648670732e-08        2
 2.46209240149462551864e-08        2
 2.48112605513777048415e-08        2
 2.50030685190632632448e-08        2
 2.51963592931701349345e-08        2
 2.53911443368034725640e-08        2
 2.55874352016858892308e-08        2
 2.57852435288427643800e-08        2
 2.59845810492924730848e-08        2
 2.61854595847423261841e-08        2
 2.63878910482893477708e-08        2
 2.65918874451269653674e-08        2
 2.67974608732568947965e-08        2
 2.70046235242068219324e-08        2
 2.72133876837530872413e-08        2
 2.74237657326495245449e-08        2
 2.76357701473615738882e-08        2
 2.78494135008064427516e-08        2
 2.80647084630983891651e-08        2
 2.82816678023003509526e-08        2
 2.85003043851810542205e-08        2
 2.87206311779782826874e-08        2
 2.89426612471675170698e-08        2
 2.91664077602370694915e-08        2
 2.93918839864688427192e-08        2
 2.96191032977255347911e-08        2
 2.98480791692432765667e-08        2
 3.00788251804310223796e-08        2
 3.03113550156757640416e-08        2
 3.05456824651543159702e-08        2
 3.07818214256508012434e-08        2
 3.10197859013809999469e-08        2
 3.12595900048227789514e-08        2
 3.15012479575532781020e-08        2
 3.17447740910919329941e-08        2
 3.19901828477506710588e-08        2
 3.22374887814902684907e-08        2
 3.24867065587837481357e-08        2
 3.27378509594857727851e-08        2
 3.29909368777094235375e-08        2
 3.32459793227093838473e-08        2
 3.35029934197722968842e-08        2
 3.37619944111134028470e-08        2
 3.40229976567807135478e-08        2
 3.42860186355658309106e-08        2
 3.45510729459221836258e-08        2
 3.48181763068896628733e-08        2
 3.50873445590271526586e-08        2
 3.53585936653517570020e-08        2
 3.56319397122858423305e-08        2
 3.59073989106105517312e-08        2
 3.61849875964275049840e-08        2
 3.64647222321274469104e-08        2
 3.67466194073668763628e-08        2
 3.70306958400514117707e-08        2
 3.73169683773275542258e-08        2
 3.76054539965816834338e-08        2
 3.78961698064471600365e-08        2
 3.81891330478185416868e-08        2
 3.84843610948743290106e-08        2
 3.87818714561071958985e-08        2
 3.90816817753626438053e-08        2
 3.93838098328848889161e-08        2
 3.96882735463716563941e-08        2
 3.99950909720366971859e-08        2
 4.03042803056805038412e-08        2
 4.06158598837697944473e-08        2
 4.09298481845244213363e-08        2
 4.12462638290134780413e-08        2
 4.15651255822598765812e-08        2
 4.18864523543527068621e-08        2
 4.22102632015690325531e-08        2
 4.25365773275039190658e-08        2
 4.28654140842092494990e-08        2
 4.31967929733417322150e-08        2
 4.35307336473189155240e-08        2
 4.38672559104849432479e-08        2
 4.42063797202852967737e-08        2
 4.45481251884498883225e-08        2
 4.48925125821860803861e-08        2
 4.52395623253805791568e-08        2
 4.55892949998105923808e-08        2
 4.59417313463647611765e-08        2
 4.62968922662726812975e-08        2
 4.66547988223446814347e-08        2
 4.70154722402212960749e-08        2
 4.73789339096314402999e-08        2
 4.77452053856613114635e-08        2
 4.81143083900326479359e-08        2
 4.84862648123907816661e-08        2
 4.88610967116032588042e-08        2
 4.92388263170674137263e-08        2
 4.96194760300289809579e-08        2
 5.00030684249108979624e-08        2
 5.03896262506515047006e-08        2
 5.07791724320540325525e-08        2
 5.11717300711460988146e-08        2
 5.15673224485496369084e-08        2
 5.19659730248619703662e-08        2
 5.23677054420465549035e-08        2
 5.27725435248353208727e-08        2
 5.31805112821419675877e-08        2
 5.35916329084851441115e-08        2
 5.40059327854237399680e-08        2
 5.44234354830027174433e-08        2
 5.48441657612101538388e-08        2
 5.52681485714460296889e-08        2
 5.56954090580013600452e-08        2
 5.61259725595496606779e-08        2
 5.65598646106500212755e-08        2
 5.69971109432607533220e-08        2
 5.74377374882658691985e-08        2
 5.78817703770128043255e-08        2
 5.83292359428620043818e-08        2
 5.87801607227491187579e-08        2
 5.92345714587580598527e-08        2
 5.96924950997073965220e-08        2
 6.01539588027483214384e-08        2
 6.06189899349757276089e-08        2
 6.10876160750503955835e-08        2
 6.15598650148351368538e-08        2
 6.20357647610426832175e-08        2
 6.25153435368971154345e-08        2
 6.29986297838069385863e-08        2
 6.34856521630522393577e-08        2
 6.39764395574842311761e-08        2
 6.44710210732386959843e-08        2
 6.49694260414612447706e-08        2
 6.54716840200474276446e-08        2
 6.59778247953953376498e-08        2
 6.64878783841726273701e-08        2
 6.70018750350959001591e-08        2
 6.75198452307250832646e-08        2
 6.80418196892709431983e-08        2
 6.85678293664173844774e-08        2
 6.90979054571564538609e-08        2
 6.96320793976388955812e-08        2
 7.01703828670382193977e-08        2
 7.07128477894299623045e-08        2
 7.12595063356841057184e-08        2
 7.18103909253735598232e-08        2
 7.23655342286965048431e-08        2
 7.29249691684144421309e-08        2
 7.34887289218038771927e-08        2
 7.40568469226244272103e-08        2
 7.46293568631012884194e-08        2
 7.52062926959240618118e-08        2
 7.57876886362593034177e-08        2
 7.63735791637802799455e-08        2
 7.69639990247115077930e-08        2
 7.75589832338900209591e-08        2
 7.81585670768409061676e-08        2
 7.87627861118706256819e-08        2
 7.93716761721754278947e-08        2
 7.99852733679670823882e-08        2
 8.06036140886134513059e-08        4
 8.12267350047972057580e-08        2
 8.18546730706902123369e-08        2
 8.24874655261458132032e-08        4
 8.31251498989063130600e-08        2
 8.37677640068292464366e-08        2
 8.44153459601299371206e-08        2
 8.50679341636415276453e-08        4
 8.57255673190932464546e-08        2
 8.63882844274045304662e-08        4
 8.70561247909985632184e-08        4
 8.77291280161335610037e-08        4
 8.84073340152506290845e-08        4
 8.90907830093414173042e-08        2
 8.97795155303333251617e-08        2
 9.04735724234929313298e-08        4
 9.11729948498492225683e-08        2
 9.18778242886334059540e-08        2
 9.25881025397394469481e-08        4
 9.33038717262035995312e-08        4
 9.40251742967013137474e-08        2
 9.47520530280654778915e-08        4
 9.54845510278230307236e-08        2
 9.62227117367513466079e-08        4
 9.69665789314552009062e-08        2
 9.77161967269618142305e-08        4
 9.84716095793376416194e-08        4
 9.92328622883254508009e-08        2
 9.99999999999999954748e-08        2
 9.99999999999999954748e-08        2
 1.00773068209446174674e-07        4
 1.01552112763456912109e-07        4
 1.02337179863251920173e-07        4
 1.03128316067218473565e-07        4
 1.03925568293671307328e-07        2
 1.04728983823635953882e-07        4
 1.05538610303652302962e-07        4
 1.06354495748601124096e-07        4
 1.07176688544550335534e-07        2
 1.08005237451625400385e-07        4
 1.08840191606900541230e-07        4
 1.09681600527313790779e-07        4
 1.10529514112602212494e-07        4
 1.11383982648262055746e-07        4
 1.12245056808530589724e-07        2
 1.13112787659392130719e-07        4
 1.13987226661605258469e-07        4
 1.14868425673755483196e-07        4
 1.15756436955330359015e-07        4
 1.16651313169819611288e-07        4
 1.17553107387836995664e-07        4
 1.18461873090268481319e-07        2
 1.19377664171443568774e-07        4
 1.20300534942332428994e-07        4
 1.21230540133765277097e-07        4
 1.22167734899679301103e-07        4
 1.23112174820388963497e-07        4
 1.24063915905883182859e-07        4
 1.25023014599145597136e-07        4
 1.25989527779502858413e-07        4
 1.26963512765997279880e-07        4
 1.27945027320787329012e-07        2
 1.28934129652571572963e-07        4
 1.29930878420041714262e-07        4
 1.30935332735360958075e-07        4
 1.31947552167670596261e-07        4
 1.32967596746621261258e-07        4
 1.33995526965933984943e-07        4
 1.35031403786987224343e-07        4
 1.36075288642433321745e-07        4
 1.37127243439840084625e-07        4
 1.38187330565363361687e-07        4
 1.39255612887446194561e-07        4
 1.40332153760548462692e-07        4
 1.41417017028902389200e-07        2
 1.42510267030299916349e-07        4
 1.43611968599907741950e-07        2
 1.44722187074113431270e-07        4
 1.45840988294398634004e-07        4
 1.46968438611244753197e-07        4
 1.48104604888067386811e-07        4
 1.49249554505182903608e-07        4
 1.50403355363802521137e-07        4
 1.51566075890060450320e-07        4
 1.52737785039071236210e-07        4
 1.53918552299020530083e-07        4
 1.55108447695284051836e-07        4
 1.56307541794581730731e-07        4
 1.57515905709162127565e-07        4
 1.58733611101020870505e-07        4
 1.59960730186148790011e-07        4
 1.61197335738815867386e-07        4
 1.62443501095886549996e-07        4
 1.63699300161170191901e-07        4
 1.64964807409802067075e-07        4
 1.66240097892661360911e-07        4
 1.67525247240821375448e-07        4
 1.68820331670036289358e-07        4
 1.70125427985258914055e-07        4
 1.71440613585197201551e-07        4
 1.72765966466903468966e-07        4
 1.74101565230401554231e-07        4
 1.75447489083345973754e-07        4
 1.76803817845720864162e-07        4
 1.78170631954572884778e-07        4
 1.79548012468783057132e-07        4
 1.80936041073871665239e-07        4
 1.82334800086844236968e-07        4
 1.83744372461072491990e-07        4
 1.85164841791215417912e-07        4
 1.86596292318174598312e-07        4
 1.88038808934091654181e-07        4
 1.89492477187381975447e-07        4
 1.90957383287809665934e-07        4
 1.92433614111598010773e-07        4
 1.93921257206583089549e-07        4
 1.95420400797405135358e-07        4
 1.96931133790742192565e-07        4
 1.98453545780580329337e-07        4
 1.99987727053528689976e-07        4
 2.01533768594173510768e-07        4
 2.03091762090473481629e-07        4
 2.04661799939198994649e-07        4
 2.06243975251409270880e-07        4
 2.07838381857975518088e-07        4
 2.09445114315146890119e-07        4
 2.11064267910155489205e-07        4
 2.12695938666869199155e-07        4
 2.14340223351485890811e-07        4
 2.15997219478271699691e-07        4
 2.17667025315345916911e-07        4
 2.19349739890506008292e-07        4
 2.21045462997101946671e-07        4
 2.22754295199955648709e-07        4
 2.24476337841322392777e-07        4
 2.26211693046902635300e-07        4
 2.27960463731898216917e-07        4
 2.29722753607115128988e-07        4
 2.31498667185116096228e-07        4
 2.33288309786415828619e-07        4
 2.35091787545728445263e-07        4
 2.36909207418263205581e-07        4
 2.38740677186064709742e-07        4
 2.40586305464406673927e-07        4
 2.42446201708233086495e-07        4
 2.44320476218648677349e-07        4
 2.46209240149462538629e-07        4
 2.48112605513777035180e-07        4
 2.50030685190632619213e-07        4
 2.51963592931701349345e-07        4
 2.53911443368034725640e-07        4
 2.55874352016858905543e-07        4
 2.57852435288427623947e-07        4
 2.59845810492924717613e-07        4
 2.61854595847423294929e-07        4
 2.63878910482893451238e-07        4
 2.65918874451269647056e-07        4
 2.67974608732568961200e-07        4
 2.70046235242068212707e-07        4
 2.72133876837530898883e-07        4
 2.74237657326495225597e-07        4
 2.76357701473615712413e-07        4
 2.78494135008064407664e-07        4
 2.80647084630983878416e-07        4
 2.82816678023003516143e-07        4
 2.85003043851810528971e-07        4
 2.87206311779782820256e-07        4
 2.89426612471675177316e-07        4
 2.91664077602370681680e-07        4
 2.93918839864688447045e-07        4
 2.96191032977255361146e-07        4
 2.98480791692432725962e-07        4
 3.00788251804310184091e-07        4
 3.03113550156757613947e-07        4
 3.05456824651543199406e-07        4
 3.07818214256507985964e-07        4
 3.10197859013809999469e-07        4
 3.12595900048227763044e-07        4
 3.15012479575532741316e-07        4
 3.17447740910919329941e-07        4
 3.19901828477506737058e-07        4
 3.22374887814902698142e-07        4
 3.24867065587837494592e-07        4
 3.27378509594857688147e-07        4
 3.29909368777094235375e-07        4
 3.32459793227093812003e-07        4
 3.35029934197722982077e-07        4
 3.37619944111133988765e-07        4
 3.40229976567807095773e-07        4
 3.42860186355658309106e-07        4
 3.45510729459221849492e-07        4
 3.48181763068896628733e-07        4
 3.50873445590271500116e-07        4
 3.53585936653517583255e-07        4
 3.56319397122858410070e-07        4
 3.59073989106105504077e-07        4
 3.61849875964275010135e-07        4
 3.64647222321274469104e-07        4
 3.67466194073668790098e-07        4
 3.70306958400514144177e-07        4
 3.73169683773275555493e-07        4
 3.76054539965816807868e-07        4
 3.78961698064471560660e-07        4
 3.81891330478185403633e-07        4
 3.84843610948743303340e-07        4
 3.87818714561071958985e-07        4
 3.90816817753626438053e-07        4
 3.93838098328848915631e-07        4
 3.96882735463716563941e-07        4
 3.99950909720366945390e-07        4
 4.03042803056805038412e-07        4
 4.06158598837697984178e-07        4
 4.09298481845244213363e-07        4
 4.12462638290134793647e-07        4
 4.15651255822598792282e-07        4
 4.18864523543527095090e-07        4
 4.22102632015690299061e-07        4
 4.25365773275039137719e-07        4
 4.28654140842092521460e-07        4
 4.31967929733417375089e-07        4
 4.35307336473189208179e-07        4
 4.38672559104849406009e-07        4
 4.42063797202852994207e-07        4
 4.45481251884498883225e-07        4
 4.48925125821860750921e-07        4
 4.52395623253805804803e-07        4
 4.55892949998105923808e-07        4
 4.59417313463647638235e-07        4
 4.62968922662726760036e-07        4
 4.66547988223446827582e-07        4
 4.70154722402212947514e-07        4
 4.73789339096314363294e-07        4
 4.77452053856613114635e-07        4
 4.81143083900326399950e-07        4
 4.84862648123907829896e-07        4
 4.88610967116032654216e-07        4
 4.92388263170674203437e-07        4
 4.96194760300289756640e-07        4
 5.00030684249109006094e-07        4
 5.03896262506515060241e-07        4
 5.07791724320540325525e-07        4
 5.11717300711460961676e-07        4
 5.15673224485496369084e-07        4
 5.19659730248619743367e-07        4
 5.23677054420465509331e-07        4
 5.27725435248353221962e-07        4
 5.31805112821419675877e-07        4
 5.35916329084851494054e-07        4
 5.40059327854237359975e-07        4
 5.44234354830027187668e-07        4
 5.48441657612101511919e-07        4
 5.52681485714460310124e-07        4
 5.56954090580013573982e-07        4
 5.61259725595496606779e-07        4
 5.65598646106500199520e-07        4
 5.69971109432607533220e-07        4
 5.74377374882658665516e-07        4
 5.78817703770127990315e-07        4
 5.83292359428619964408e-07        4
 5.87801607227491147874e-07        4
 5.92345714587580558822e-07        4
 5.96924950997073965220e-07        4
 6.01539588027483267323e-07        4
 6.06189899349757170210e-07        4
 6.10876160750503982305e-07        4
 6.15598650148351421477e-07        4
 6.20357647610426805705e-07        4
 6.25153435368971180815e-07        4
 6.29986297838069279984e-07        4
 6.34856521630522314168e-07        4
 6.39764395574842417640e-07        4
 6.44710210732386959843e-07        4
 6.49694260414612500645e-07        4
 6.54716840200474329386e-07        4
 6.59778247953953270619e-07        4
 6.64878783841726273701e-07        4
 6.70018750350958975121e-07        4
 6.75198452307250832646e-07        4
 6.80418196892709431983e-07        4
 6.85678293664173765364e-07        4
 6.90979054571564565079e-07        4
 6.96320793976389008752e-07        4
 7.01703828670382220446e-07        4
 7.07128477894299543635e-07        4
 7.12595063356841057184e-07        4
 7.18103909253735651172e-07        4
 7.23655342286964969021e-07        4
 7.29249691684144368370e-07        4
 7.34887289218038771927e-07        4
 7.40568469226244219163e-07        4
 7.46293568631012990073e-07        4
 7.52062926959240723997e-07        4
 7.57876886362592981237e-07        4
 7.63735791637802693576e-07        4
 7.69639990247115104400e-07        4
 7.75589832338900209591e-07        4
 7.81585670768409088146e-07        4
 7.87627861118706309758e-07        4
 7.93716761721754278947e-07        4
 7.99852733679670797412e-07        4
 8.06036140886134539529e-07        4
 8.12267350047972004641e-07        4
 8.18546730706902123369e-07        4
 8.24874655261458105562e-07        4
 8.31251498989063236479e-07        4
 8.37677640068292384957e-07        4
 8.44153459601299318267e-07        4
 8.50679341636415329393e-07        4
 8.57255673190932517485e-07        4
 8.63882844274045357601e-07        4
 8.70561247909985605714e-07        4
 8.77291280161335610037e-07        4
 8.84073340152506264375e-07        4
 8.90907830093414225981e-07        4
 8.97795155303333198677e-07        4
 9.04735724234929339768e-07        4
 9.11729948498492119804e-07        4
 9.18778242886333953661e-07        4
 9.25881025397394495951e-07        4
 9.33038717262036048252e-07        4
 9.40251742967013243353e-07        4
 9.47520530280654805385e-07        4
 9.54845510278230280766e-07        4
 9.62227117367513492548e-07        4
 9.69665789314552141410e-07        4
 9.77161967269618142305e-07        4
 9.84716095793376495603e-07        4
 9.92328622883254481539e-07        4
 9.99999999999999954748e-07        4
 9.99999999999999954748e-07        4
 1.00773068209446177321e-06        4
 1.01552112763456906815e-06        4
 1.02337179863251909585e-06        4
 1.03128316067218468271e-06        4
 1.03925568293671309975e-06        4
 1.04728983823635956529e-06        4
 1.05538610303652297668e-06        4
 1.06354495748601118802e-06        4
 1.07176688544550343475e-06        4
 1.08005237451625395091e-06        4
 1.08840191606900543877e-06        4
 1.09681600527313801367e-06        4
 1.10529514112602207200e-06        4
 1.11383982648262061040e-06        4
 1.12245056808530584430e-06        4
 1.13112787659392125426e-06        4
 1.13987226661605242588e-06        4
 1.14868425673755475255e-06        4
 1.15756436955330348427e-06        4
 1.16651313169819619228e-06        4
 1.17553107387836995664e-06        4
 1.18461873090268473378e-06        4
 1.19377664171443563480e-06        4
 1.20300534942332418406e-06        4
 1.21230540133765277097e-06        4
 1.22167734899679311691e-06        4
 1.23112174820388958203e-06        4
 1.24063915905883182859e-06        4
 1.25023014599145597136e-06        4
 1.25989527779502842531e-06        4
 1.26963512765997285174e-06        4
 1.27945027320787344893e-06        4
 1.28934129652571562375e-06        4
 1.29930878420041719556e-06        4
 1.30935332735360947487e-06        4
 1.31947552167670590967e-06        4
 1.32967596746621277140e-06        4
 1.33995526965933990237e-06        4
 1.35031403786987213755e-06        4
 1.36075288642433316451e-06        4
 1.37127243439840074038e-06        4
 1.38187330565363361687e-06        4
 1.39255612887446189267e-06        4
 1.40332153760548483868e-06        4
 1.41417017028902410375e-06        4
 1.42510267030299921643e-06        4
 1.43611968599907731362e-06        4
 1.44722187074113436564e-06        4
 1.45840988294398639298e-06        4
 1.46968438611244742609e-06        4
 1.48104604888067397399e-06        4
 1.49249554505182903608e-06        4
 1.50403355363802521137e-06        4
 1.51566075890060429144e-06        4
 1.52737785039071246798e-06        4
 1.53918552299020545965e-06        4
 1.55108447695284057130e-06        4
 1.56307541794581730731e-06        4
 1.57515905709162122272e-06        4
 1.58733611101020870505e-06        4
 1.59960730186148779423e-06        4
 1.61197335738815877974e-06        4
 1.62443501095886544702e-06        4
 1.63699300161170186607e-06        4
 1.64964807409802072369e-06        4
 1.66240097892661350323e-06        4
 1.67525247240821380742e-06        4
 1.68820331670036278770e-06        4
 1.70125427985258924643e-06        4
 1.71440613585197196257e-06        4
 1.72765966466903468966e-06        4
 1.74101565230401533055e-06        4
 1.75447489083345973754e-06        4
 1.76803817845720853574e-06        4
 1.78170631954572890071e-06        4
 1.79548012468783046544e-06        4
 1.80936041073871665239e-06        4
 1.82334800086844236968e-06        4
 1.83744372461072491990e-06        4
 1.85164841791215407325e-06        4
 1.86596292318174603606e-06        4
 1.88038808934091670063e-06        4
 1.89492477187381975447e-06        4
 1.90957383287809644758e-06        4
 1.92433614111598005479e-06        4
 1.93921257206583084256e-06        4
 1.95420400797405156534e-06        4
 1.96931133790742160801e-06        4
 1.98453545780580318749e-06        4
 1.99987727053528716446e-06        4
 2.01533768594173526650e-06        4
 2.03091762090473481629e-06        4
 2.04661799939198968179e-06        4
 2.06243975251409281468e-06        4
 2.07838381857975533970e-06        4
 2.09445114315146890119e-06        4
 2.11064267910155468029e-06        4
 2.12695938666869183273e-06        4
 2.14340223351485885517e-06        4
 2.15997219478271710279e-06        4
 2.17667025315345890441e-06        4
 2.19349739890506013586e-06        4
 2.21045462997101941377e-06        4
 2.22754295199955638121e-06        4
 2.24476337841322376896e-06        4
 2.26211693046902640594e-06        4
 2.27960463731898195741e-06        4
 2.29722753607115134282e-06        4
 2.31498667185116085640e-06        4
 2.33288309786415839207e-06        4
 2.35091787545728424087e-06        4
 2.36909207418263189699e-06        4
 2.38740677186064677979e-06        4
 2.40586305464406705691e-06        4
 2.42446201708233075907e-06        4
 2.44320476218648687937e-06        4
 2.46209240149462528041e-06        4
 2.48112605513777035180e-06        4
 2.50030685190632650977e-06        4
 2.51963592931701370521e-06        4
 2.53911443368034715052e-06        4
 2.55874352016858926719e-06        4
 2.57852435288427634535e-06        4
 2.59845810492924707025e-06        4
 2.61854595847423263165e-06        4
 2.63878910482893472414e-06        4
 2.65918874451269647056e-06        4
 2.67974608732568961200e-06        4
 2.70046235242068191531e-06        4
 2.72133876837530898883e-06        4
 2.74237657326495257360e-06        4
 2.76357701473615712413e-06        4
 2.78494135008064439427e-06        4
 2.80647084630983878416e-06        4
 2.82816678023003516143e-06        4
 2.85003043851810497207e-06        4
 2.87206311779782788492e-06        4
 2.89426612471675156140e-06        4
 2.91664077602370660504e-06        4
 2.93918839864688436457e-06        4
 2.96191032977255339970e-06        4
 2.98480791692432736550e-06        4
 3.00788251804310205267e-06        4
 3.03113550156757603359e-06        4
 3.05456824651543199406e-06        4
 3.07818214256508007140e-06        4
 3.10197859013809999469e-06        4
 3.12595900048227784220e-06        4
 3.15012479575532762491e-06        4
 3.17447740910919351117e-06        4
 3.19901828477506737058e-06        4
 3.22374887814902676966e-06        4
 3.24867065587837473416e-06        4
 3.27378509594857709323e-06        4
 3.29909368777094224787e-06        4
 3.32459793227093833179e-06        4
 3.35029934197722992665e-06        4
 3.37619944111133988765e-06        4
 3.40229976567807138125e-06        4
 3.42860186355658298518e-06        4
 3.45510729459221807141e-06        4
 3.48181763068896649909e-06        4
 3.50873445590271489528e-06        4
 3.53585936653517583255e-06        4
 3.56319397122858399482e-06        4
 3.59073989106105514665e-06        4
 3.61849875964275020723e-06        4
 3.64647222321274490280e-06        4
 3.67466194073668800686e-06        4
 3.70306958400514101825e-06        4
 3.73169683773275555493e-06        4
 3.76054539965816818456e-06        4
 3.78961698064471603012e-06        4
 3.81891330478185456572e-06        4
 3.84843610948743345692e-06        4
 3.87818714561071990749e-06        4
 3.90816817753626438053e-06        4
 3.93838098328848883867e-06        4
 3.96882735463716606293e-06        4
 3.99950909720366977153e-06        4
 4.03042803056805059588e-06        4
 4.06158598837697941826e-06        4
 4.09298481845244202775e-06        4
 4.12462638290134772472e-06        4
 4.15651255822598749931e-06        4
 4.18864523543527063327e-06        4
 4.22102632015690320237e-06        4
 4.25365773275039158895e-06        4
 4.28654140842092521460e-06        4
 4.31967929733417322150e-06        4
 4.35307336473189176415e-06        4
 4.38672559104849437773e-06        4
 4.42063797202852951855e-06        4
 4.45481251884498819697e-06        4
 4.48925125821860772097e-06        4
 4.52395623253805804803e-06        4
 4.55892949998105902632e-06        4
 4.59417313463647680586e-06        4
 4.62968922662726812975e-06        4
 4.66547988223446816994e-06        4
 4.70154722402212958102e-06        4
 4.73789339096314416234e-06        4
 4.77452053856613093459e-06        4
 4.81143083900326442302e-06        4
 4.84862648123907787545e-06        4
 4.88610967116032611865e-06        4
 4.92388263170674118734e-06        4
 4.96194760300289841343e-06        4
 5.00030684249108963742e-06        4
 5.03896262506515017890e-06        4
 5.07791724320540304350e-06        4
 5.11717300711461025204e-06        4
 5.15673224485496347908e-06        4
 5.19659730248619701015e-06        4
 5.23677054420465530507e-06        4
 5.27725435248353200786e-06        4
 5.31805112821419739404e-06        4
 5.35916329084851515230e-06        4
 5.40059327854237381151e-06        4
 5.44234354830027187668e-06        4
 5.48441657612101511919e-06        4
 5.52681485714460310124e-06        4
 5.56954090580013637510e-06        4
 5.61259725595496543251e-06        4
 5.65598646106500178344e-06        4
 5.69971109432607596747e-06        4
 5.74377374882658729043e-06        4
 5.78817703770128011491e-06        4
 5.83292359428620006760e-06        4
 5.87801607227491147874e-06        4
 5.92345714587580579998e-06        4
 5.96924950997073901693e-06        4
 6.01539588027483288499e-06        4
 6.06189899349757212562e-06        4
 6.10876160750504003480e-06        4
 6.15598650148351442653e-06        4
 6.20357647610426805705e-06        4
 6.25153435368971159639e-06        4
 6.29986297838069279984e-06        4
 6.34856521630522292992e-06        4
 6.39764395574842375288e-06        4
 6.44710210732386959843e-06        4
 6.49694260414612458293e-06        4
 6.54716840200474265858e-06        4
 6.59778247953953312971e-06        4
 6.64878783841726273701e-06        4
 6.70018750350959017473e-06        4
 6.75198452307250832646e-06        4
 6.80418196892709347279e-06        4
 6.85678293664173765364e-06        4
 6.90979054571564480376e-06        4
 6.96320793976389051103e-06        4
 7.01703828670382262798e-06        4
 7.07128477894299585987e-06        4
 7.12595063356841078360e-06        4
 7.18103909253735629996e-06        4
 7.23655342286964969021e-06        4
 7.29249691684144453073e-06        4
 7.34887289218038793103e-06        4
 7.40568469226244219163e-06        4
 7.46293568631012947721e-06        4
 7.52062926959240702821e-06        4
 7.57876886362592981237e-06        4
 7.63735791637802672400e-06        4
 7.69639990247115062048e-06        4
 7.75589832338900124888e-06        4
 7.81585670768409151673e-06        4
 7.87627861118706288582e-06        4
 7.93716761721754236595e-06        4
 7.99852733679670712709e-06        4
 8.06036140886134497177e-06        4
 8.12267350047972068168e-06        4
 8.18546730706902123369e-06        4
 8.24874655261458147914e-06        4
 8.31251498989063109424e-06        4
 8.37677640068292363781e-06        4
 8.44153459601299360618e-06        4
 8.50679341636415329393e-06        4
 8.57255673190932432782e-06        4
 8.63882844274045315249e-06        4
 8.70561247909985605714e-06        4
 8.77291280161335652388e-06        4
 8.84073340152506243199e-06        4
 8.90907830093414225981e-06        4
 8.97795155303333092798e-06        4
 9.04735724234929233889e-06        4
 9.11729948498492162156e-06        4
 9.18778242886333974837e-06        4
 9.25881025397394474775e-06        4
 9.33038717262036027076e-06        4
 9.40251742967013243353e-06        4
 9.47520530280654763033e-06        4
 9.54845510278230365469e-06        4
 9.62227117367513407845e-06        4
 9.69665789314551972004e-06        4
 9.77161967269618057601e-06        4
 9.84716095793376495603e-06        4
 9.92328622883254608594e-06        4
 9.99999999999999912396e-06        4
 9.99999999999999912396e-06        4
 1.00773068209446177321e-05        4
 1.01552112763456923756e-05        4
 1.02337179863251909585e-05        4
 1.03128316067218468271e-05        4
 1.03925568293671322681e-05        4
 1.04728983823635952294e-05        4
 1.05538610303652306138e-05        4
 1.06354495748601114567e-05        4
 1.07176688544550343475e-05        4
 1.08005237451625399326e-05        4
 1.08840191606900543877e-05        4
 1.09681600527313805602e-05        4
 1.10529514112602219905e-05        4
 1.11383982648262056805e-05        4
 1.12245056808530597136e-05        4
 1.13112787659392133896e-05        4
 1.13987226661605251058e-05        4
 1.14868425673755479490e-05        4
 1.15756436955330348427e-05        4
 1.16651313169819610758e-05        4
 1.17553107387836982959e-05        4
 1.18461873090268481848e-05        4
 1.19377664171443580420e-05        4
 1.20300534942332418406e-05        4
 1.21230540133765272862e-05        4
 1.22167734899679303220e-05        4
 1.23112174820388962438e-05        4
 1.24063915905883174389e-05        4
 1.25023014599145601371e-05        4
 1.25989527779502846766e-05        4
 1.26963512765997289409e-05        4
 1.27945027320787344893e-05        4
 1.28934129652571579316e-05        4
 1.29930878420041706850e-05        4
 1.30935332735360947487e-05        4
 1.31947552167670590967e-05        4
 1.32967596746621260199e-05        4
 1.33995526965933990237e-05        4
 1.35031403786987226460e-05        4
 1.36075288642433316451e-05        4
 1.37127243439840090978e-05        4
 1.38187330565363361687e-05        4
 1.39255612887446185032e-05        4
 1.40332153760548466927e-05        4
 1.41417017028902401905e-05        4
 1.42510267030299913173e-05        4
 1.43611968599907722892e-05        4
 1.44722187074113440799e-05        4
 1.45840988294398639298e-05        4
 1.46968438611244742609e-05        4
 1.48104604888067393164e-05        4
 1.49249554505182903608e-05        4
 1.50403355363802525372e-05        4
 1.51566075890060429144e-05        4
 1.52737785039071229858e-05        4
 1.53918552299020529024e-05        4
 1.55108447695284035954e-05        4
 1.56307541794581739201e-05        4
 1.57515905709162113801e-05        4
 1.58733611101020853564e-05        4
 1.59960730186148775188e-05        4
 1.61197335738815873739e-05        4
 1.62443501095886548937e-05        4
 1.63699300161170203547e-05        4
 1.64964807409802063898e-05        4
 1.66240097892661371499e-05        4
 1.67525247240821389212e-05        4
 1.68820331670036270300e-05        4
 1.70125427985258928878e-05        4
 1.71440613585197196257e-05        4
 1.72765966466903452025e-05        4
 1.74101565230401524585e-05        4
 1.75447489083345982224e-05        4
 1.76803817845720862045e-05        4
 1.78170631954572890071e-05        4
 1.79548012468783055014e-05        4
 1.80936041073871656769e-05        4
 1.82334800086844215793e-05        4
 1.83744372461072483520e-05        4
 1.85164841791215398854e-05        4
 1.86596292318174603606e-05        4
 1.88038808934091665828e-05        4
 1.89492477187381962742e-05        4
 1.90957383287809661699e-05        4
 1.92433614111598005479e-05        4
 1.93921257206583101196e-05        4
 1.95420400797405148063e-05        4
 1.96931133790742186212e-05        4
 1.98453545780580335690e-05        4
 1.99987727053528691035e-05        4
 2.01533768594173518180e-05        4
 2.03091762090473481629e-05        4
 2.04661799939198985119e-05        4
 2.06243975251409256057e-05        4
 2.07838381857975508559e-05        4
 2.09445114315146864708e-05        4
 2.11064267910155476499e-05        4
 2.12695938666869183273e-05        4
 2.14340223351485877046e-05        4
 2.15997219478271710279e-05        4
 2.17667025315345890441e-05        4
 2.19349739890506030527e-05        4
 2.21045462997101915966e-05        4
 2.22754295199955655062e-05        4
 2.24476337841322385366e-05        4
 2.26211693046902649065e-05        4
 2.27960463731898204211e-05        4
 2.29722753607115100401e-05        4
 2.31498667185116085640e-05        4
 2.33288309786415839207e-05        4
 2.35091787545728449498e-05        4
 2.36909207418263206639e-05        4
 2.38740677186064711860e-05        4
 2.40586305464406688751e-05        4
 2.42446201708233058966e-05        4
 2.44320476218648687937e-05        4
 2.46209240149462544982e-05        4
 2.48112605513777043651e-05        4
 2.50030685190632642506e-05        4
 2.51963592931701336640e-05        4
 2.53911443368034698111e-05        4
 2.55874352016858909778e-05        4
 2.57852435288427634535e-05        4
 2.59845810492924723966e-05        4
 2.61854595847423271635e-05        4
 2.63878910482893455473e-05        4
 2.65918874451269638586e-05        4
 2.67974608732568935789e-05        6
 2.70046235242068225412e-05        4
 2.72133876837530865002e-05        4
 2.74237657326495240420e-05        4
 2.76357701473615729353e-05        4
 2.78494135008064414016e-05        4
 2.80647084630983886886e-05        4
 2.82816678023003516143e-05        4
 2.85003043851810531088e-05        4
 2.87206311779782805433e-05        4
 2.89426612471675173081e-05        4
 2.91664077602370660504e-05        4
 2.93918839864688436457e-05        4
 2.96191032977255356911e-05        4
 2.98480791692432736550e-05        4
 3.00788251804310205267e-05        4
 3.03113550156757603359e-05        4
 3.05456824651543216347e-05        4
 3.07818214256508015611e-05        4
 3.10197859013809965588e-05        4
 3.12595900048227758809e-05        4
 3.15012479575532754021e-05        4
 3.17447740910919325706e-05        4
 3.19901828477506703177e-05        4
 3.22374887814902676966e-05        4
 3.24867065587837507297e-05        6
 3.27378509594857734733e-05        4
 3.29909368777094258668e-05        6
 3.32459793227093841649e-05        4
 3.35029934197722984194e-05        4
 3.37619944111134005706e-05        6
 3.40229976567807155066e-05        4
 3.42860186355658315459e-05        4
 3.45510729459221857963e-05        4
 3.48181763068896649909e-05        4
 3.50873445590271481058e-05        4
 3.53585936653517574784e-05        6
 3.56319397122858416422e-05        6
 3.59073989106105514665e-05        6
 3.61849875964275003782e-05        6
 3.64647222321274515691e-05        6
 3.67466194073668792216e-05        6
 3.70306958400514076414e-05        6
 3.73169683773275580904e-05        6
 3.76054539965816784575e-05        6
 3.78961698064471603012e-05        6
 3.81891330478185405750e-05        6
 3.84843610948743311811e-05        6
 3.87818714561071939927e-05        6
 3.90816817753626404171e-05        6
 3.93838098328848866926e-05        6
 3.96882735463716606293e-05        6
 3.99950909720366926331e-05        6
 4.03042803056805076529e-05        6
 4.06158598837697958767e-05        6
 4.09298481845244202775e-05        6
 4.12462638290134772472e-05        6
 4.15651255822598817693e-05        6
 4.18864523543527114149e-05        6
 4.22102632015690303296e-05        6
 4.25365773275039192776e-05        6
 4.28654140842092538401e-05        6
 4.31967929733417322150e-05        6
 4.35307336473189193356e-05        6
 4.38672559104849403891e-05        6
 4.42063797202853019618e-05        6
 4.45481251884498853579e-05        6
 4.48925125821860772097e-05        6
 4.52395623253805804803e-05        6
 4.55892949998105902632e-05        6
 4.59417313463647612824e-05        6
 4.62968922662726796034e-05        6
 4.66547988223446816994e-05        6
 4.70154722402212958102e-05        6
 4.73789339096314382352e-05        6
 4.77452053856613161222e-05        6
 4.81143083900326476183e-05        6
 4.84862648123907821426e-05        6
 4.88610967116032628805e-05        6
 4.92388263170674152615e-05        6
 4.96194760300289807462e-05        6
 5.00030684249108946801e-05        6
 5.03896262506515034830e-05        6
 5.07791724320540372112e-05        6
 5.11717300711461042144e-05        6
 5.15673224485496347908e-05        6
 5.19659730248619717956e-05        6
 5.23677054420465564388e-05        6
 5.27725435248353234668e-05        6
 5.31805112821419722464e-05        6
 5.35916329084851447468e-05        6
 5.40059327854237398092e-05        6
 5.44234354830027170728e-05        6
 5.48441657612101494978e-05        6
 5.52681485714460327065e-05        6
 5.56954090580013603628e-05        6
 5.61259725595496611014e-05        6
 5.65598646106500212226e-05        6
 5.69971109432607528984e-05        6
 5.74377374882658695162e-05        6
 5.78817703770128028432e-05        6
 5.83292359428619989819e-05        6
 5.87801607227491181755e-05        6
 5.92345714587580563057e-05        6
 5.96924950997073969455e-05        6
 6.01539588027483288499e-05        6
 6.06189899349757229502e-05        6
 6.10876160750503969599e-05        6
 6.15598650148351357950e-05        6
 6.20357647610426856527e-05        6
 6.25153435368971108817e-05        6
 6.29986297838069279984e-05        6
 6.34856521630522326874e-05        6
 6.39764395574842409170e-05        6
 6.44710210732386942902e-05        6
 6.49694260414612458293e-05        6
 6.54716840200474282799e-05        6
 6.59778247953953346852e-05        6
 6.64878783841726239820e-05        6
 6.70018750350959000532e-05        6
 6.75198452307250798765e-05        6
 6.80418196892709347279e-05        6
 6.85678293664173765364e-05        6
 6.90979054571564565079e-05        6
 6.96320793976389084984e-05        6
 7.01703828670382178095e-05        6
 7.07128477894299636809e-05        6
 7.12595063356841044479e-05        6
 7.18103909253735663877e-05        6
 7.23655342286965070665e-05        6
 7.29249691684144486954e-05        6
 7.34887289218038826984e-05        6
 7.40568469226244219163e-05        6
 7.46293568631012913840e-05        6
 7.52062926959240685880e-05        6
 7.57876886362593015119e-05        6
 7.63735791637802706282e-05        6
 7.69639990247115095929e-05        6
 7.75589832338900091006e-05        6
 7.81585670768409083910e-05        6
 7.87627861118706288582e-05        6
 7.93716761721754304358e-05        6
 7.99852733679670848234e-05        6
 8.06036140886134564940e-05        6
 8.12267350047972034287e-05        6
 8.18546730706902123369e-05        6
 8.24874655261458147914e-05        6
 8.31251498989063177187e-05        6
 8.37677640068292363781e-05        6
 8.44153459601299394500e-05        6
 8.50679341636415329393e-05        6
 8.57255673190932432782e-05        6
 8.63882844274045349131e-05        6
 8.70561247909985673477e-05        6
 8.77291280161335686270e-05        6
 8.84073340152506344843e-05        6
 8.90907830093414225981e-05        6
 8.97795155303333160561e-05        6
 9.04735724234929233889e-05        6
 9.11729948498492162156e-05        6
 9.18778242886333907074e-05        6
 9.25881025397394508657e-05        6
 9.33038717262036027076e-05        6
 9.40251742967013209471e-05        6
 9.47520530280654763033e-05        6
 9.54845510278230297707e-05        6
 9.62227117367513509489e-05        6
 9.69665789314552039766e-05        6
 9.77161967269618125364e-05        6
 9.84716095793376360078e-05        6
 9.92328622883254473069e-05        6
 1.00000000000000004792e-04        6
 1.00000000000000004792e-04        6
 1.00773068209446167156e-04        6
 1.01552112763456808559e-04        6
 1.02337179863252024782e-04        6
 1.03128316067218478436e-04        6
 1.03925568293671309128e-04        6
 1.04728983823635843874e-04        6
 1.05538610303652414558e-04        6
 1.06354495748601124731e-04        6
 1.07176688544550333311e-04        6
 1.08005237451625290906e-04        6
 1.08840191606900655685e-04        6
 1.09681600527313798826e-04        6
 1.10529514112602206353e-04        6
 1.11383982648261941608e-04        6
 1.12245056808530705556e-04        6
 1.13112787659392133896e-04        6
 1.13987226661605247670e-04        6
 1.14868425673755357517e-04        6
 1.15756436955330473788e-04        6
 1.16651313169819617534e-04        6
 1.17553107387836989735e-04        6
 1.18461873090268366652e-04        6
 1.19377664171443692229e-04        6
 1.20300534942332425182e-04        6
 1.21230540133765286414e-04        6
 1.22167734899679181248e-04        6
 1.23112174820389077634e-04        6
 1.24063915905883194717e-04        6
 1.25023014599145608147e-04        6
 1.25989527779502707852e-04        6
 1.26963512765997397829e-04        6
 1.27945027320787338117e-04        6
 1.28934129652571565763e-04        6
 1.29930878420041591654e-04        6
 1.30935332735361093176e-04        6
 1.31947552167670597743e-04        6
 1.32967596746621277140e-04        6
 1.33995526965933841159e-04        6
 1.35031403786987355209e-04        6
 1.36075288642433319839e-04        6
 1.37127243439840080814e-04        6
 1.38187330565363205833e-04        6
 1.39255612887446327333e-04        6
 1.40332153760548466927e-04        6
 1.41417017028902395129e-04        6
 1.42510267030299770871e-04        6
 1.43611968599907885522e-04        6
 1.44722187074113430635e-04        6
 1.45840988294398629134e-04        6
 1.46968438611244607084e-04        6
 1.48104604888067535465e-04        6
 1.49249554505182906996e-04        6
 1.50403355363802528760e-04        6
 1.51566075890060273290e-04        6
 1.52737785039071412817e-04        6
 1.53918552299020549353e-04        6
 1.55108447695284049506e-04        6
 1.56307541794581590124e-04        6
 1.57515905709162289984e-04        6
 1.58733611101020873893e-04        6
 1.59960730186148775188e-04        6
 1.61197335738815704332e-04        6
 1.62443501095886698015e-04        6
 1.63699300161170176442e-04        6
 1.64964807409802077451e-04        6
 1.66240097892661188540e-04        6
 1.67525247240821558619e-04        6
 1.68820331670036270300e-04        6
 1.70125427985258915325e-04        6
 1.71440613585197026850e-04        6
 1.72765966466903648537e-04        6
 1.74101565230401538137e-04        6
 1.75447489083345968671e-04        6
 1.76803817845720679085e-04        6
 1.78170631954573073031e-04        6
 1.79548012468783027909e-04        6
 1.80936041073871656769e-04        6
 1.82334800086844032833e-04        6
 1.83744372461072680031e-04        6
 1.85164841791215405630e-04        6
 1.86596292318174603606e-04        6
 1.88038808934091469316e-04        6
 1.89492477187382172806e-04        6
 1.90957383287809648147e-04        6
 1.92433614111597991927e-04        6
 1.93921257206582911461e-04        6
 1.95420400797405324246e-04        6
 1.96931133790742172660e-04        6
 1.98453545780580308585e-04        6
 1.99987727053528704588e-04        6
 2.01533768594173301339e-04        6
 2.03091762090473488406e-04        6
 2.04661799939198998672e-04        6
 2.06243975251409249281e-04        6
 2.07838381857975725399e-04        6
 2.09445114315146864708e-04        6
 2.11064267910155469723e-04        6
 2.12695938666869190049e-04        6
 2.14340223351485673758e-04        6
 2.15997219478271710279e-04        6
 2.17667025315345903994e-04        6
 2.19349739890506016974e-04        6
 2.21045462997102146359e-04        6
 2.22754295199955627957e-04        6
 2.24476337841322392142e-04        6
 2.26211693046902642288e-04        6
 2.27960463731897967042e-04        6
 2.29722753607115127506e-04        6
 2.31498667185116085640e-04        6
 2.33288309786415818878e-04        6
 2.35091787545728679891e-04        6
 2.36909207418263220192e-04        6
 2.38740677186064691531e-04        6
 2.40586305464406688751e-04        6
 2.42446201708232828573e-04        6
 2.44320476218648952212e-04        6
 2.46209240149462544982e-04        6
 2.48112605513777016546e-04        6
 2.50030685190632412113e-04        6
 2.51963592931701634795e-04        6
 2.53911443368034725216e-04        6
 2.55874352016858923331e-04        6
 2.57852435288427356708e-04        6
 2.59845810492924974688e-04        6
 2.61854595847423271635e-04        6
 2.63878910482893448697e-04        6
 2.65918874451269394640e-04        6
 2.67974608732569213616e-04        6
 2.70046235242068198307e-04        6
 2.72133876837530892107e-04        6
 2.74237657326494976145e-04        6
 2.76357701473616034285e-04        6
 2.78494135008064414016e-04        6
 2.80647084630983886886e-04        6
 2.82816678023003217988e-04        6
 2.85003043851810836020e-04        6
 2.87206311779782791881e-04        6
 2.89426612471675173081e-04        6
 2.91664077602370403006e-04        6
 2.93918839864688754941e-04        6
 2.96191032977255323030e-04        6
 2.98480791692432750103e-04        6
 3.00788251804309900335e-04        6
 3.03113550156757915067e-04        6
 3.05456824651543189242e-04        6
 3.07818214256508002058e-04        6
 3.10197859013809694537e-04        6
 3.12595900048228097622e-04        6
 3.15012479575532754021e-04        6
 3.17447740910919312153e-04        6
 3.19901828477506364364e-04        6
 3.22374887814903029332e-04        6
 3.24867065587837466640e-04        6
 3.27378509594857707628e-04        6
 3.29909368777093906303e-04        6
 3.32459793227094153358e-04        6
 3.35029934197722957089e-04        6
 3.37619944111133992153e-04        6
 3.40229976567806816252e-04        6
 3.42860186355658667825e-04        6
 3.45510729459221803753e-04        6
 3.48181763068896622804e-04        6
 3.50873445590271142245e-04        6
 3.53585936653517940702e-04        6
 3.56319397122858375765e-04        6
 3.59073989106105514665e-04        6
 3.61849875964274664969e-04        6
 3.64647222321274840952e-04        6
 3.67466194073668805768e-04        6
 3.70306958400514103519e-04        6
 3.73169683773275160776e-04        6
 3.76054539965817191151e-04        6
 3.78961698064471603012e-04        6
 3.81891330478185432856e-04        6
 3.84843610948743311811e-04        6
 3.87818714561072373607e-04        6
 3.90816817753626417724e-04        6
 3.93838098328848894032e-04        6
 3.96882735463716606293e-04        6
 3.99950909720366519755e-04        6
 4.03042803056805022319e-04        6
 4.06158598837697958767e-04        6
 4.09298481845244256985e-04        6
 4.12462638290135206152e-04        6
 4.15651255822598790588e-04        6
 4.18864523543527127701e-04        6
 4.22102632015690262639e-04        6
 4.25365773275038759095e-04        6
 4.28654140842092538401e-04        6
 4.31967929733417376360e-04        6
 4.35307336473189220461e-04        6
 4.38672559104849851125e-04        6
 4.42063797202853019618e-04        6
 4.45481251884498840026e-04        6
 4.48925125821860772097e-04        6
 4.52395623253805357570e-04        6
 4.55892949998105956842e-04        6
 4.59417313463647667034e-04        6
 4.62968922662726782482e-04        6
 4.66547988223447291332e-04        6
 4.70154722402212944549e-04        6
 4.73789339096314409457e-04        6
 4.77452053856613134117e-04        6
 4.81143083900325934082e-04        6
 4.84862648123907807873e-04        6
 4.88610967116032655910e-04        6
 4.92388263170674125510e-04        6
 4.96194760300290322458e-04        6
 5.00030684249109028117e-04        6
 5.03896262506514994173e-04        6
 5.07791724320540345007e-04        6
 5.11717300711460472938e-04        6
 5.15673224485496293698e-04        6
 5.19659730248619717956e-04        6
 5.23677054420465591493e-04        6
 5.27725435248353790321e-04        6
 5.31805112821419736016e-04        6
 5.35916329084851488125e-04        6
 5.40059327854237425197e-04        6
 5.44234354830026682837e-04        6
 5.48441657612101481425e-04        6
 5.52681485714460259302e-04        6
 5.56954090580013562971e-04        6
 5.61259725595497139562e-04        6
 5.65598646106500822089e-04        6
 5.69971109432607569642e-04        6
 5.74377374882658708714e-04        6
 5.78817703770127377910e-04        6
 5.83292359428620559025e-04        8
 5.87801607227491154650e-04        6
 5.92345714587580603715e-04        6
 5.96924950997073386696e-04        6
 6.01539588027483911915e-04        6
 6.06189899349757243055e-04        6
 6.10876160750503942494e-04        8
 6.15598650148350815849e-04        6
 6.20357647610427507048e-04        6
 6.25153435368971163028e-04        8
 6.29986297838069334194e-04        6
 6.34856521630521703457e-04        6
 6.39764395574842978376e-04        6
 6.44710210732386997112e-04        6
 6.49694260414612539609e-04        8
 6.54716840200473605173e-04        8
 6.59778247953953997373e-04        8
 6.64878783841726266925e-04        6
 6.70018750350958973427e-04        8
 6.75198452307250148244e-04        8
 6.80418196892710052011e-04        8
 6.85678293664173819574e-04        8
 6.90979054571564483764e-04        8
 6.96320793976388271833e-04        8
 7.01703828670382882826e-04        8
 7.07128477894299663914e-04        8
 7.12595063356841044479e-04        8
 7.18103909253734904936e-04        8
 7.23655342286965721187e-04        8
 7.29249691684144378534e-04        8
 7.34887289218038772774e-04        8
 7.40568469226243406012e-04        8
 7.46293568631013672782e-04        8
 7.52062926959240658775e-04        8
 7.57876886362593015119e-04        8
 7.63735791637801947340e-04        8
 7.69639990247115881976e-04        8
 7.75589832338900199427e-04        8
 7.81585670768409138121e-04        8
 7.87627861118705475431e-04        8
 7.93716761721755090404e-04        8
 7.99852733679670821129e-04        8
 8.06036140886134564940e-04        8
 8.12267350047971166925e-04        8
 8.18546730706902936521e-04        8
 8.24874655261458120808e-04        8
 8.31251498989063150082e-04        8
 8.37677640068292417991e-04        8
 8.44153459601298472928e-04        8
 8.50679341636415356498e-04        8
 8.57255673190932486992e-04        8
 8.63882844274045376236e-04        8
 8.70561247909986540838e-04        8
 8.77291280161335632060e-04        8
 8.84073340152506290633e-04        8
 8.90907830093414280191e-04        8
 8.97795155303332320304e-04        8
 9.04735724234929342309e-04        8
 9.11729948498492216366e-04        8
 9.18778242886333961284e-04        8
 9.25881025397395484439e-04        8
 9.33038717262036081286e-04        8
 9.40251742967013236577e-04        8
 9.47520530280654763033e-04        8
 9.54845510278229349030e-04        8
 9.62227117367513455279e-04        8
 9.69665789314552066872e-04        8
 9.77161967269618179574e-04        8
 9.84716095793377417175e-04        8
 9.92328622883254527279e-04        8
 1.00000000000000002082e-03        8
 1.00000000000000002082e-03        8
 1.00773068209446172577e-03        8
 1.01552112763456819401e-03        8
 1.02337179863252027492e-03        8
 1.03128316067218478436e-03        8
 1.03925568293671303707e-03        8
 1.04728983823635843874e-03        8
 1.05538610303652414558e-03        8
 1.06354495748601108468e-03        8
 1.07176688544550341442e-03        8
 1.08005237451625282774e-03        8
 1.08840191606900658396e-03        8
 1.09681600527313806957e-03        8
 1.10529514112602217195e-03        8
 1.11383982648261947029e-03        8
 1.12245056808530697424e-03        8
 1.13112787659392136606e-03        8
 1.13987226661605247670e-03        8
 1.14868425673755360228e-03        8
 1.15756436955330465656e-03        8
 1.16651313169819606692e-03        8
 1.17553107387836984314e-03        8
 1.18461873090268355810e-03        8
 1.19377664171443692229e-03        8
 1.20300534942332430603e-03        8
 1.21230540133765289125e-03        8
 1.22167734899679175826e-03        8
 1.23112174820389072213e-03        8
 1.24063915905883183875e-03        8
 1.25023014599145608147e-03        8
 1.25989527779502724116e-03        8
 1.26963512765997403250e-03        8
 1.27945027320787354380e-03        8
 1.28934129652571571184e-03        8
 1.29930878420041586233e-03        8
 1.30935332735361087755e-03        8
 1.31947552167670603164e-03        8
 1.32967596746621260877e-03        8
 1.33995526965933857422e-03        8
 1.35031403786987349788e-03        8
 1.36075288642433303576e-03        8
 1.37127243439840091656e-03        8
 1.38187330565363222096e-03        8
 1.39255612887446327333e-03        8
 1.40332153760548477769e-03        8
 1.41417017028902395129e-03        8
 1.42510267030299770871e-03        8
 1.43611968599907874680e-03        8
 1.44722187074113441477e-03        8
 1.45840988294398629134e-03        8
 1.46968438611244601663e-03        8
 1.48104604888067551728e-03        8
 1.49249554505182912417e-03        8
 1.50403355363802528760e-03        8
 1.51566075890060278711e-03        8
 1.52737785039071391133e-03        8
 1.53918552299020538511e-03        8
 1.55108447695284038664e-03        8
 1.56307541794581568440e-03        8
 1.57515905709162289984e-03        8
 1.58733611101020879314e-03        8
 1.59960730186148791451e-03        8
 1.61197335738815709753e-03        8
 1.62443501095886708857e-03        8
 1.63699300161170187284e-03        8
 1.64964807409802077451e-03        8
 1.66240097892661172277e-03        8
 1.67525247240821553198e-03        8
 1.68820331670036264879e-03        8
 1.70125427985258915325e-03        8
 1.71440613585197021429e-03        8
 1.72765966466903648537e-03        8
 1.74101565230401532716e-03        8
 1.75447489083345974092e-03        8
 1.76803817845720689927e-03        8
 1.78170631954573067610e-03        8
 1.79548012468783027909e-03        8
 1.80936041073871656769e-03        8
 1.82334800086844054517e-03        8
 1.83744372461072669189e-03        8
 1.85164841791215411052e-03        8
 1.86596292318174598185e-03        8
 1.88038808934091463895e-03        8
 1.89492477187382167385e-03        8
 1.90957383287809669831e-03        8
 1.92433614111598002769e-03        8
 1.93921257206582900619e-03        8
 1.95420400797405345930e-03        8
 1.96931133790742172660e-03        8
 1.98453545780580319427e-03        8
 1.99987727053528704588e-03        8
 2.01533768594173295918e-03        8
 2.03091762090473488406e-03        8
 2.04661799939198987830e-03        8
 2.06243975251409281807e-03        8
 2.07838381857975741662e-03        8
 2.09445114315146875550e-03        8
 2.11064267910155475144e-03        8
 2.12695938666869173786e-03        8
 2.14340223351485673758e-03        8
 2.15997219478271731963e-03        8
 2.17667025315345903994e-03        8
 2.19349739890506000711e-03        8
 2.21045462997102168043e-03        8
 2.22754295199955633378e-03        8
 2.24476337841322381300e-03        8
 2.26211693046902626025e-03        8
 2.27960463731897988726e-03        8
 2.29722753607115122085e-03        8
 2.31498667185116085640e-03        8
 2.33288309786415818878e-03        8
 2.35091787545728663628e-03        8
 2.36909207418263198508e-03        8
 2.38740677186064691531e-03        8
 2.40586305464406688751e-03        8
 2.42446201708232823152e-03        8
 2.44320476218648930528e-03        8
 2.46209240149462566666e-03        8
 2.48112605513777038230e-03        8
 2.50030685190632401271e-03        8
 2.51963592931701623953e-03        8
 2.53911443368034714374e-03        8
 2.55874352016858923331e-03        8
 2.57852435288427389234e-03        8
 2.59845810492924985530e-03        8
 2.61854595847423260793e-03        8
 2.63878910482893448697e-03        8
 2.65918874451269351272e-03        8
 2.67974608732569202774e-03        8
 2.70046235242068187465e-03        8
 2.72133876837530892107e-03        8
 2.74237657326494976145e-03        8
 2.76357701473616034285e-03        8
 2.78494135008064414016e-03        8
 2.80647084630983876044e-03        8
 2.82816678023003250514e-03        8
 2.85003043851810803494e-03        8
 2.87206311779782813565e-03        8
 2.89426612471675205607e-03        8
 2.91664077602370392164e-03        8
 2.93918839864688733257e-03        8
 2.96191032977255333872e-03        8
 2.98480791692432717577e-03        8
 3.00788251804309878651e-03       10
 3.03113550156757904225e-03        8
 3.05456824651543189242e-03        8
 3.07818214256508002058e-03        8
 3.10197859013809683695e-03        8
 3.12595900048228108464e-03        8
 3.15012479575532775705e-03        8
 3.17447740910919333837e-03        8
 3.19901828477506386048e-03        8
 3.22374887814903029332e-03        8
 3.24867065587837455798e-03        8
 3.27378509594857718470e-03        8
 3.29909368777093906303e-03        8
 3.32459793227094175042e-03       10
 3.35029934197722967931e-03        8
 3.37619944111134002995e-03        8
 3.40229976567806794568e-03        8
 3.42860186355658678667e-03        8
 3.45510729459221847121e-03       10
 3.48181763068896666172e-03       10
 3.50873445590271131403e-03        8
 3.53585936653517951545e-03        8
 3.56319397122858419133e-03       10
 3.59073989106105514665e-03       10
 3.61849875964274664969e-03       10
 3.64647222321274862636e-03       10
 3.67466194073668784084e-03       10
 3.70306958400514092677e-03       10
 3.73169683773275171618e-03       10
 3.76054539965817169467e-03       10
 3.78961698064471603012e-03       10
 3.81891330478185400329e-03       10
 3.84843610948743322653e-03        8
 3.87818714561072351923e-03       10
 3.90816817753626439408e-03       10
 3.93838098328848883189e-03       10
 3.96882735463716627977e-03       10
 3.99950909720366530598e-03       10
 4.03042803056805065687e-03       10
 4.06158598837697958767e-03       10
 4.09298481845244213617e-03       10
 4.12462638290135227837e-03       10
 4.15651255822598823114e-03       10
 4.18864523543527062649e-03       10
 4.22102632015690284323e-03       10
 4.25365773275038737411e-03       10
 4.28654140842092516717e-03       10
 4.31967929733417365518e-03       10
 4.35307336473189209619e-03       10
 4.38672559104849851125e-03       10
 4.42063797202853041302e-03       10
 4.45481251884498850868e-03       10
 4.48925125821860761255e-03       10
 4.52395623253805390096e-03       10
 4.55892949998105978526e-03       10
 4.59417313463647645350e-03       10
 4.62968922662726749956e-03       10
 4.66547988223447313016e-03       10
 4.70154722402212933707e-03       10
 4.73789339096314376931e-03       10
 4.77452053856613177485e-03       10
 4.81143083900325944924e-03       10
 4.84862648123907807873e-03       10
 4.88610967116032655910e-03       10
 4.92388263170674168878e-03       10
 4.96194760300290322458e-03       10
 5.00030684249109028117e-03       10
 5.03896262506514994173e-03       10
 5.07791724320540323323e-03       10
 5.11717300711460494622e-03       10
 5.15673224485496337066e-03       10
 5.19659730248619739640e-03       10
 5.23677054420465526441e-03       10
 5.27725435248353746953e-03       10
 5.31805112821419692648e-03       10
 5.35916329084851466441e-03       10
 5.40059327854237360145e-03       10
 5.44234354830026682837e-03       10
 5.48441657612101524794e-03       10
 5.52681485714460324354e-03       10
 5.56954090580013584655e-03       10
 5.61259725595497117878e-03       10
 5.65598646106500735353e-03       10
 5.69971109432607526274e-03       10
 5.74377374882658643662e-03       10
 5.78817703770127464646e-03       10
 5.83292359428620559025e-03       10
 5.87801607227491154650e-03       10
 5.92345714587580625399e-03       10
 5.96924950997073343328e-03       10
 6.01539588027483890231e-03       10
 6.06189899349757199687e-03       10
 6.10876160750504007546e-03       10
 6.15598650148350794165e-03       10
 6.20357647610427463680e-03       10
 6.25153435368971163028e-03       10
 6.29986297838069312510e-03       10
 6.34856521630521725141e-03       10
 6.39764395574842978376e-03       10
 6.44710210732386997112e-03       10
 6.49694260414612496241e-03       10
 6.54716840200473583489e-03       10
 6.59778247953953997373e-03       10
 6.64878783841726245241e-03       10
 6.70018750350959060164e-03       10
 6.75198452307250104876e-03       10
 6.80418196892710117063e-03       10
 6.85678293664173776206e-03       10
 6.90979054571564527132e-03       10
 6.96320793976388293517e-03       10
 7.01703828670382969562e-03       10
 7.07128477894299577178e-03       10
 7.12595063356841109531e-03       10
 7.18103909253734948304e-03       10
 7.23655342286965742871e-03       10
 7.29249691684144465270e-03       10
 7.34887289218038794458e-03       10
 7.40568469226243492748e-03       10
 7.46293568631013759518e-03       10
 7.52062926959240658775e-03       10
 7.57876886362592993435e-03       10
 7.63735791637801947340e-03       10
 7.69639990247115816924e-03       10
 7.75589832338900199427e-03       10
 7.81585670768409138121e-03       10
 7.87627861118705453747e-03       10
 7.93716761721755155456e-03       10
 7.99852733679670864497e-03       10
 8.06036140886134434835e-03       10
 8.12267350047971188609e-03       10
 8.18546730706902828101e-03       10
 8.24874655261458207545e-03       10
 8.31251498989063128398e-03       10
 8.37677640068292504727e-03       10
 8.44153459601298429560e-03       10
 8.50679341636415356498e-03       10
 8.57255673190932508676e-03       10
 8.63882844274045311184e-03       10
 8.70561247909986540838e-03       10
 8.77291280161335632060e-03       10
 8.84073340152506312317e-03       10
 8.90907830093414301875e-03       10
 8.97795155303332190200e-03       10
 9.04735724234929233889e-03       10
 9.11729948498492259734e-03       10
 9.18778242886333917916e-03       10
 9.25881025397395397702e-03       10
 9.33038717262035972866e-03       10
 9.40251742967013193208e-03       10
 9.47520530280654763033e-03       10
 9.54845510278229392398e-03       10
 9.62227117367513498647e-03       10
 9.69665789314552023503e-03       10
 9.77161967269618222942e-03       10
 9.84716095793377460543e-03       10
 9.92328622883254483911e-03       10
 1.00000000000000002082e-02       10
 1.00000000000000002082e-02       10
 1.00773068209446120536e-02       10
 1.01552112763456797717e-02       10
 1.02337179863251984124e-02       12
 1.03128316067218478436e-02       10
 1.03925568293671260339e-02       10
 1.04728983823635848210e-02       10
 1.05538610303652358180e-02       10
 1.06354495748601125815e-02       12
 1.07176688544550289400e-02       12
 1.08005237451625282774e-02       10
 1.08840191606900602017e-02       10
 1.09681600527313793947e-02       10
 1.10529514112602152143e-02       10
 1.11383982648261947029e-02       10
 1.12245056808530641046e-02       10
 1.13112787659392140943e-02       10
 1.13987226661605191291e-02       10
 1.14868425673755360228e-02       12
 1.15756436955330409277e-02       12
 1.16651313169819619703e-02       10
 1.17553107387836936609e-02       10
 1.18461873090268364483e-02       12
 1.19377664171443631513e-02       12
 1.20300534942332417593e-02       12
 1.21230540133765215399e-02       12
 1.22167734899679188837e-02       12
 1.23112174820389011498e-02       12
 1.24063915905883170865e-02       12
 1.25023014599145547432e-02       12
 1.25989527779502719779e-02       12
 1.26963512765997342535e-02       12
 1.27945027320787337033e-02       12
 1.28934129652571501795e-02       12
 1.29930878420041577559e-02       12
 1.30935332735361009693e-02       12
 1.31947552167670598827e-02       12
 1.32967596746621195825e-02       12
 1.33995526965933840075e-02       12
 1.35031403786987289073e-02       12
 1.36075288642433303576e-02       12
 1.37127243439840017930e-02       12
 1.38187330565363222096e-02       12
 1.39255612887446266618e-02       12
 1.40332153760548469096e-02       12
 1.41417017028902386455e-02       12
 1.42510267030299779545e-02       12
 1.43611968599907883354e-02       12
 1.44722187074113432803e-02       12
 1.45840988294398642144e-02       12
 1.46968438611244592990e-02       12
 1.48104604888067547391e-02       12
 1.49249554505182912417e-02       12
 1.50403355363802511413e-02       12
 1.51566075890060287384e-02       12
 1.52737785039071399806e-02       12
 1.53918552299020534174e-02       12
 1.55108447695284056012e-02       12
 1.56307541794581672523e-02       12
 1.57515905709162268300e-02       12
 1.58733611101020966050e-02       12
 1.59960730186148800125e-02       12
 1.61197335738815783479e-02       12
 1.62443501095886691510e-02       12
 1.63699300161170291368e-02       12
 1.64964807409802051430e-02       12
 1.66240097892661267687e-02       12
 1.67525247240821531514e-02       12
 1.68820331670036377636e-02       12
 1.70125427985258932673e-02       12
 1.71440613585197125512e-02       12
 1.72765966466903661547e-02       12
 1.74101565230401628126e-02       12
 1.75447489083345974092e-02       12
 1.76803817845720759316e-02       12
 1.78170631954573076283e-02       12
 1.79548012468783123319e-02       12
 1.80936041073871643758e-02       12
 1.82334800086844141254e-02       12
 1.83744372461072669189e-02       12
 1.85164841791215506461e-02       12
 1.86596292318174580838e-02       12
 1.88038808934091576652e-02       12
 1.89492477187382171722e-02       12
 1.90957383287809756567e-02       12
 1.92433614111598011442e-02       12
 1.93921257206583000365e-02       12
 1.95420400797405337256e-02       12
 1.96931133790742285417e-02       12
 1.98453545780580310753e-02       12
 1.99987727053528609178e-02       12
 2.01533768594173295918e-02       12
 2.03091762090473575142e-02       12
 2.04661799939198987830e-02       12
 2.06243975251409160376e-02       12
 2.07838381857975741662e-02       12
 2.09445114315146979633e-02       12
 2.11064267910155492491e-02       12
 2.12695938666869061029e-02       12
 2.14340223351485656411e-02       12
 2.15997219478271836046e-02       12
 2.17667025315345930014e-02       12
 2.19349739890505879281e-02       12
 2.21045462997102176717e-02       12
 2.22754295199955737461e-02       12
 2.24476337841322398647e-02       12
 2.26211693046902521942e-02       12
 2.27960463731897988726e-02       12
 2.29722753607115234842e-02       12
 2.31498667185116094314e-02       12
 2.33288309786415723468e-02       12
 2.35091787545728680975e-02       12
 2.36909207418263337286e-02       12
 2.38740677186064717552e-02       12
 2.40586305464406541299e-02       12
 2.42446201708232840499e-02       12
 2.44320476218648809097e-02       12
 2.46209240149462549319e-02       12
 2.48112605513776916799e-02       12
 2.50030685190632401271e-02       12
 2.51963592931701493849e-02       12
 2.53911443368034714374e-02       12
 2.55874352016858784553e-02       12
 2.57852435288427397908e-02       12
 2.59845810492924864099e-02       14
 2.61854595847423252120e-02       14
 2.63878910482893344613e-02       12
 2.65918874451269368619e-02       14
 2.67974608732569063996e-02       14
 2.70046235242068222160e-02       12
 2.72133876837530735981e-02       14
 2.74237657326494958798e-02       14
 2.76357701473615886834e-02       14
 2.78494135008064414016e-02       14
 2.80647084630983728593e-02       14
 2.82816678023003233167e-02       14
 2.85003043851810682063e-02       14
 2.87206311779782813565e-02       14
 2.89426612471675170912e-02       14
 2.91664077602370383491e-02       14
 2.93918839864688724584e-02       14
 2.96191032977255325198e-02       14
 2.98480791692432752271e-02       14
 3.00788251804309895998e-02       14
 3.03113550156757921572e-02       14
 3.05456824651543189242e-02       14
 3.07818214256508002058e-02       14
 3.10197859013809675022e-02       14
 3.12595900048228125812e-02       14
 3.15012479575532758358e-02       14
 3.17447740910919359858e-02       14
 3.19901828477506394721e-02       14
 3.22374887814903046679e-02       14
 3.24867065587837455798e-02       14
 3.27378509594857675102e-02       14
 3.29909368777093897629e-02       14
 3.32459793227094166368e-02       14
 3.35029934197722950584e-02       14
 3.37619944111134037690e-02       14
 3.40229976567806777221e-02       14
 3.42860186355658652646e-02       14
 3.45510729459221829774e-02       14
 3.48181763068896657498e-02       14
 3.50873445590271157424e-02       14
 3.53585936653517951545e-02       14
 3.56319397122858427807e-02       14
 3.59073989106105523339e-02       14
 3.61849875964274647622e-02       14
 3.64647222321274888657e-02       14
 3.67466194073668775411e-02       16
 3.70306958400514127372e-02       14
 3.73169683773275154270e-02       14
 3.76054539965817169467e-02       14
 3.78961698064471594338e-02       14
 3.81891330478185409003e-02       14
 3.84843610948743114486e-02       14
 3.87818714561072377944e-02       14
 3.90816817753626630227e-02       14
 3.93838098328848917884e-02       14
 3.96882735463716385116e-02       14
 3.99950909720366565292e-02       14
 4.03042803056805273854e-02       14
 4.06158598837697976114e-02       14
 4.09298481845244005450e-02       14
 4.12462638290135227837e-02       14
 4.15651255822599013934e-02       14
 4.18864523543527114691e-02       14
 4.22102632015690093503e-02       14
 4.25365773275038772105e-02       14
 4.28654140842092690189e-02       14
 4.31967929733417382865e-02       14
 4.35307336473188949411e-02       14
 4.38672559104849868472e-02       14
 4.42063797202853214774e-02       14
 4.45481251884498885563e-02       16
 4.48925125821860518394e-02       14
 4.52395623253805390096e-02       14
 4.55892949998106186693e-02       14
 4.59417313463647628002e-02       16
 4.62968922662726489747e-02       14
 4.66547988223447313016e-02       16
 4.70154722402213176569e-02       14
 4.73789339096314376931e-02       14
 4.77452053856612865235e-02       16
 4.81143083900325979618e-02       14
 4.84862648123908085429e-02       14
 4.88610967116032621216e-02       16
 4.92388263170673926017e-02       14
 4.96194760300290305111e-02       16
 5.00030684249109236283e-02       16
 5.03896262506515063562e-02       14
 5.07791724320540080462e-02       16
 5.11717300711460459928e-02       14
 5.15673224485496614622e-02       16
 5.19659730248619722293e-02       16
 5.23677054420465248885e-02       16
 5.27725435248353746953e-02       16
 5.31805112821419970204e-02       16
 5.35916329084851483788e-02       16
 5.40059327854237117283e-02       16
 5.44234354830026648142e-02       16
 5.48441657612101785002e-02       16
 5.52681485714460324354e-02       16
 5.56954090580013341794e-02       16
 5.61259725595497152573e-02       16
 5.65598646106500804742e-02       16
 5.69971109432607508927e-02       16
 5.74377374882658678357e-02       16
 5.78817703770127395257e-02       16
 5.83292359428620593720e-02       16
 5.87801607227491224039e-02       16
 5.92345714587580590704e-02       16
 5.96924950997073378023e-02       16
 6.01539588027483890231e-02       16
 6.06189899349757199687e-02       16
 6.10876160750503938157e-02       16
 6.15598650148350759470e-02       16
 6.20357647610427498375e-02       16
 6.25153435368971110986e-02       16
 6.29986297838069364552e-02       16
 6.34856521630521725141e-02       16
 6.39764395574843047765e-02       16
 6.44710210732386962418e-02       16
 6.49694260414612478893e-02       16
 6.54716840200473687572e-02       16
 6.59778247953954066762e-02       16
 6.64878783841726245241e-02       16
 6.70018750350959008122e-02       16
 6.75198452307250174265e-02       16
 6.80418196892710047674e-02       16
 6.85678293664173793553e-02       16
 6.90979054571564527132e-02       16
 6.96320793976388241475e-02       16
 7.01703828670382917521e-02       16
 7.07128477894299611872e-02       16
 7.12595063356841057489e-02       16
 7.18103909253734878915e-02       16
 7.23655342286965708176e-02       16
 7.29249691684144413228e-02       16
 7.34887289218038863847e-02       16
 7.40568469226243475401e-02       16
 7.46293568631013759518e-02       16
 7.52062926959240762859e-02       16
 7.57876886362593010782e-02       18
 7.63735791637801947340e-02       16
 7.69639990247115851618e-02       18
 7.75589832338900164732e-02       18
 7.81585670768409068732e-02       16
 7.87627861118705419052e-02       18
 7.93716761721755120762e-02       16
 7.99852733679670829803e-02       18
 8.06036140886134538919e-02       18
 8.12267350047971153915e-02       16
 8.18546730706902897490e-02       18
 8.24874655261458034072e-02       18
 8.31251498989063197786e-02       18
 8.37677640068291984310e-02       18
 8.44153459601298533643e-02       18
 8.50679341636415703443e-02       18
 8.57255673190932543370e-02       18
 8.63882844274044825461e-02       18
 8.70561247909986540838e-02       18
 8.77291280161336117782e-02       18
 8.84073340152506381706e-02       18
 8.90907830093413816153e-02       18
 8.97795155303332259589e-02       18
 9.04735724234929789001e-02       18
 9.11729948498492259734e-02       18
 9.18778242886333501582e-02       18
 9.25881025397395363008e-02       18
 9.33038717262036493283e-02       18
 9.40251742967013193208e-02       18
 9.47520530280654277311e-02       18
 9.54845510278229392398e-02       18
 9.62227117367513984370e-02       18
 9.69665789314552023503e-02       18
 9.77161967269617737220e-02       18
 9.84716095793377460543e-02       18
 9.92328622883255073717e-02       18
 1.00000000000000005551e-01       18
  1.00772990604604900655e-01       18
 1.01551956353957847923e-01       18
 1.02336943435366409250e-01       18
 1.03127998393161612878e-01       18
 1.03925168131457815179e-01       18
 1.04728499916933837088e-01       18
 1.05538041381635375182e-01       18
 1.06353840525799450689e-01       18
 1.07175945720700327435e-01       18
 1.08004405711517786903e-01       18
 1.08839269620227177549e-01       20
 1.09680586948512098777e-01       18
 1.10528407580699608581e-01       18
 1.11382781786717816042e-01       18
 1.12243760225076719128e-01       20
 1.13111393945871788191e-01       20
 1.13985734393811002918e-01       20
 1.14866833411265065190e-01       20
 1.15754743241341273574e-01       20
 1.16649516530981364748e-01       20
 1.17551206334082891658e-01       18
 1.18459866114645040458e-01       20
 1.19375549749938775212e-01       20
 1.20298311533701254850e-01       20
 1.21228206179355063599e-01       20
 1.22165288823252532469e-01       20
 1.23109615027944707677e-01       20
 1.24061240785475979109e-01       20
 1.25020222520703938596e-01       20
 1.25986617094645120263e-01       20
 1.26960481807846276014e-01       20
 1.27941874403782018810e-01       20
 1.28930853072278639448e-01       20
 1.29927476452964291154e-01       20
 1.30931803638745930529e-01       20
 1.31943894179313153669e-01       20
 1.32963808084669093956e-01       20
 1.33991605828688437052e-01       20
 1.35027348352703413514e-01       20
 1.36071097069116936362e-01       20
 1.37122913865044021575e-01       20
 1.38182861105981269478e-01       20
 1.39251001639504712326e-01       20
 1.40327398798996305640e-01       20
 1.41412116407398952278e-01       20
 1.42505218781001086192e-01       20
 1.43606770733249872185e-01       20
 1.44716837578594409441e-01       20
 1.45835485136358244951e-01       20
 1.46962779734642251528e-01       20
 1.48098788214257232054e-01       22
 1.49243577932687110366e-01       20
 1.50397216768082958582e-01       20
 1.51559773123287500063e-01       20
 1.52731315929891031669e-01       22
 1.53911914652318460028e-01       22
 1.55101639291948395494e-01       22
 1.56300560391263276827e-01       22
 1.57508749038032580536e-01       22
 1.58726276869527255231e-01       22
 1.59953216076767879006e-01       22
 1.61189639408804596954e-01       22
 1.62435620177031170286e-01       22
 1.63691232259531332938e-01       22
 1.64956550105459454070e-01       22
 1.66231648739455006858e-01       22
 1.67516603766090843575e-01       22
 1.68811491374355915340e-01       22
 1.70116388342173074921e-01       22
 1.71431372040951240932e-01       22
 1.72756520440173061415e-01       22
 1.74091912112017910275e-01       22
 1.75437626236020827175e-01       22
 1.76793742603767123356e-01       22
 1.78160341623623597052e-01       22
 1.79537504325506136471e-01       22
 1.80925312365684431981e-01       22
 1.82323848031623186872e-01       22
 1.83733194246861741838e-01       22
 1.85153434575930447847e-01       22
 1.86584653229305674760e-01       22
 1.88026935068402789586e-01       24
 1.89480365610608103566e-01       22
 1.90945031034349094190e-01       24
 1.92421018184204484225e-01       22
 1.93908414576053456102e-01       22
 1.95407308402264667802e-01       24
 1.96917788536925486564e-01       24
 1.98439944541111662479e-01       24
 1.99973866668197580720e-01       24
 2.01519645869207814082e-01       24
 2.03077373798209864786e-01       24
 2.04647142817748400878e-01       24
 2.06229046004321958652e-01       24
 2.07823177153901667014e-01       24
 2.09429630787492659927e-01       24
 2.11048502156738704283e-01       24
 2.12679887249569626873e-01       24
 2.14323882795893094766e-01       24
 2.15980586273329749902e-01       24
 2.17650095912993168934e-01       24
 2.19332510705314148725e-01       26
 2.21027930405910205680e-01       24
 2.22736455541500483202e-01       24
 2.24458187415866261549e-01       24
 2.26193228115857347671e-01       24
 2.27941680517445455223e-01       24
 2.29703648291823825378e-01       24
 2.31479235911554309668e-01       24
 2.33268548656761776083e-01       24
 2.35071692621376671095e-01       26
 2.36888774719425626580e-01       26
 2.38719902691370444714e-01       24
 2.40565185110496682075e-01       26
 2.42424731389351222344e-01       26
 2.44298651786229503724e-01       26
 2.46187057411713428046e-01       26
 2.48090060235259229904e-01       26
 2.50007773091836416057e-01       26
 2.51940309688618246931e-01       26
 2.53887784611723732464e-01       26
 2.55850313333011891714e-01       26
 2.57828012216928192935e-01       26
 2.59820998527404589673e-01       26
 2.61829390434812014909e-01       26
 2.63853307022967387141e-01       26
 2.65892868296194240241e-01       26
 2.67948195186438309356e-01       26
 2.70019409560437795292e-01       26
 2.72106634226949528621e-01       26
 2.74209992944030478412e-01       26
 2.76329610426375604781e-01       26
 2.78465612352712776900e-01       28
 2.80618125373254756472e-01       28
 2.82787277117208413202e-01       28
 2.84973196200342393514e-01       28
 2.87176012232613242503e-01       28
 2.89395855825850367715e-01       28
 2.91632858601500122298e-01       28
 2.93887153198430395307e-01       28
 2.96158873280795043037e-01       28
 2.98448153545959327104e-01       28
 3.00755129732486303773e-01       28
 3.03079938628185718841e-01       28
 3.05422718078223798255e-01       28
 3.07783606993297376153e-01       28
 3.10162745357869640284e-01       28
 3.12560274238470492403e-01       28
 3.14976335792061190588e-01       28
 3.17411073274462607330e-01       30
 3.19864631048849767936e-01       28
 3.22337154594311392497e-01       30
 3.24828790514476217766e-01       30
 3.27339686546204822193e-01       30
 3.29869991568350007238e-01       30
 3.32419855610584347172e-01       30
 3.34989429862295240437e-01       30
 3.37578866681550349149e-01       30
 3.40188319604130373630e-01       30
 3.42817943352633602849e-01       30
 3.45467893845649187679e-01       30
 3.48138328207002412107e-01       32
 3.50829404775071074241e-01       32
 3.53541283112173587710e-01       30
 3.56274124014030246776e-01       32
 3.59028089519297100018e-01       32
 3.61803342919173764880e-01       32
 3.64600048767085405110e-01       32
 3.67418372888439759283e-01       32
 3.70258482390459608968e-01       32
 3.73120545672090409006e-01       32
 3.76004732433986244011e-01       32
 3.78911213688570724933e-01       32
 3.81840161770177655143e-01       34
 3.84791750345269356615e-01       32
 3.87766154422732933771e-01       32
 3.90763550364258360759e-01       32
 3.93784115894794672919e-01       34
 3.96828030113087759645e-01       32
 3.99895473502300591306e-01       32
 4.02986627940713604268e-01       34
 4.06101676712509407352e-01       34
 4.09240804518640033383e-01       34
 4.12404197487778623188e-01       34
 4.15592043187355375533e-01       34
 4.18804530634679039736e-01       34
 4.22041850308144783632e-01       34
 4.25304194158527271163e-01       34
 4.28591755620363279444e-01       34
 4.31904729623419858520e-01       36
 4.35243312604252974296e-01       34
 4.38607702517854969315e-01       36
 4.41998098849391396481e-01       36
 4.45414702626029501698e-01       36
 4.48857716428857411728e-01       36
 4.52327344404896580787e-01       36
 4.55823792279205275424e-01       38
 4.59347267367077150002e-01       36
 4.62897978586334024609e-01       36
 4.66476136469712254762e-01       36
 4.70081953177347189321e-01       38
 4.73715642509351109180e-01       38
 4.77377419918492140738e-01       38
 4.81067502522967371803e-01       38
 4.84786109119277219826e-01       38
 4.88533460195198887543e-01       38
 4.92309777942858850519e-01       38
 4.96115286271908373372e-01       38
 4.99950210822798890575e-01       40
 5.03814778980161581678e-01       38
 5.07709219886289142565e-01       40
 5.11633764454722861359e-01       40
 5.15588645383944221834e-01       40
 5.19574097171171755960e-01       40
 5.23590356126265477066e-01       62
 5.27637660385738893609e-01       40
 5.31716249926877604359e-01       62
 5.35826366581970026104e-01       62
 5.39968254052644258678e-01       42
 5.44142157924320302165e-01       42
 5.48348325680769632662e-01       42
 5.52587006718790130222e-01       42
 5.56858452362993805451e-01       44
 5.61162915880707879879e-01       44
 5.65500652496992550766e-01       44
 5.69871919409773775023e-01       44
 5.74276975805092959604e-01       44
 5.78716082872475445775e-01       44
 5.83189503820417010083e-01       44
 5.87697503891990713498e-01       44
 5.92240350380573210565e-01       46
 5.96818312645694182272e-01       46
 6.01431662129006783246e-01       46
 6.06080672370382989023e-01       46
 6.10765619024132400128e-01       46
 6.15486779875345724200e-01       48
 6.20244434856367377051e-01       48
 6.25038866063391651551e-01       50
 6.29870357773190669981e-01       48
 6.34739196459968679775e-01       50
 6.39645670812348798862e-01       50
 6.44590071750490212210e-01       50
 6.49572692443337262880e-01       50
 6.54593828326003546181e-01       52
 6.59653777117287010157e-01       52
 6.64752838837324833143e-01       52
 6.69891315825381639115e-01       54
 6.75069512757775824774e-01       54
 6.80287736665945441672e-01       54
 6.85546296954652412126e-01       54
 6.90845505420328631629e-01       56
 6.96185676269563180618e-01       58
 7.01567126137731866820e-01       58
 7.06990174107773095002e-01       56
 7.12455141729105845272e-01       58
 7.17962353036696310227e-01       60
 7.23512134570270193379e-01       60
 7.29104815393674554613e-01       60
 7.34740727114389757801e-01       62
 7.40420203903189300121e-01       62
 7.46143582513957515090e-01       62
 7.51911202303652714818e-01       62
 7.57723405252431647661e-01       64
 7.63580535983925057231e-01       66
 7.69482941785672558410e-01       66
 7.75430972629713277655e-01       68
 7.81424981193336920526e-01       68
 7.87465322879997264849e-01       70
 7.93552355840381085095e-01       72
 7.99686440993648051112e-01       72
 8.05867942048828056478e-01       72
 8.12097225526388299954e-01       74
 8.18374660779964124835e-01       76
 8.24700620018260499577e-01       78
 8.31075478327120142907e-01       80
 8.37499613691763844514e-01       90
 8.43973407019203425428e-01       86
 8.50497242160825561719e-01       86
 8.57071505935152466726e-01       90
 8.63696588150776767279e-01       94
 8.70372881629475236842e-01       94
 8.77100782229500275378e-01       96
 8.83880688869050135104e-01       98
 8.90713003549924886570e-01      102
 8.97598131381359687353e-01      104
 9.04536480604046788656e-01      108
 9.11528462614339618497e-01      112
 9.18574491988648156315e-01      118
 9.25674986508017161313e-01      126
 9.32830367182902020495e-01      132
 9.40041058278127228398e-01      136
 9.47307487338045373093e-01      146
 9.54630085211887191576e-01      162
 9.62009286079306580319e-01      178
 9.69445527476126445166e-01      202
 9.76939250320278840256e-01      224
 9.84490898937952385594e-01      266
 9.92100921089932752395e-01      366
 9.99769767998156533295e-01     1988
 9.99770537146582594090e-01     1942
 9.99771306295600403757e-01     1948
 9.99772075445209962297e-01     1958
 9.99772844595411158686e-01     1956
 9.99773613746204103947e-01     1944
 9.99774382897588798080e-01     1942
 9.99775152049565130064e-01     1960
 9.99775921202133321941e-01     1984
 9.99776690355293151669e-01     1970
 9.99777459509044730268e-01     1960
 9.99778228663388057740e-01     1964
 9.99778997818323134084e-01     1986
 9.99779766973849959300e-01     1984
 9.99780536129968422365e-01     2006
 9.99781305286678745325e-01     1980
 9.99782074443980706135e-01     2010
 9.99782843601874415818e-01     1998
 9.99783612760359874372e-01     2000
 9.99784381919436970776e-01     1970
 9.99785151079105927074e-01     2042
 9.99785920239366521223e-01     2028
 9.99786689400218975265e-01     1988
 9.99787458561663067158e-01     2014
 9.99788227723698907923e-01     2024
 9.99788996886326497560e-01     2012
 9.99789766049545836069e-01     2022
 9.99790535213356923450e-01     2004
 9.99791304377759648681e-01     2012
 9.99792073542754233806e-01     2042
 9.99792842708340456781e-01     2040
 9.99793611874518539651e-01     2022
 9.99794381041288260370e-01     2026
 9.99795150208649729962e-01     2044
 9.99795919376602948425e-01     2032
 9.99796688545147915761e-01     2036
 9.99797457714284631969e-01     2022
 9.99798226884013097049e-01     2044
 9.99798996054333311001e-01     2082
 9.99799765225245273825e-01     2058
 9.99800534396748874499e-01     2052
 9.99801303568844335068e-01     2066
 9.99802072741531544509e-01     2132
 9.99802841914810391799e-01     2056
 9.99803611088681098984e-01     2078
 9.99804380263143444019e-01     2096
 9.99805149438197648948e-01     2106
 9.99805918613843491727e-01     2070
 9.99806687790081194400e-01     2092
 9.99807456966910534923e-01     2084
 9.99808226144331735341e-01     2090
 9.99808995322344573609e-01     2110
 9.99809764500949160748e-01     2138
 9.99810533680145607782e-01     2104
 9.99811302859933692666e-01     2114
 9.99812072040313637444e-01     2130
 9.99812841221285220072e-01     2128
 9.99813610402848551573e-01     2108
 9.99814379585003742967e-01     2110
 9.99815148767750572212e-01     2140
 9.99815917951089261351e-01     2130
 9.99816687135019588339e-01     2148
 9.99817456319541775223e-01     2196
 9.99818225504655710978e-01     2124
 9.99818994690361284583e-01     2160
 9.99819763876658718083e-01     2180
 9.99820533063547900454e-01     2174
 9.99821302251028720676e-01     2152
 9.99822071439101400792e-01     2174
 9.99822840627765829780e-01     2180
 9.99823609817022007640e-01     2198
 9.99824379006869934372e-01     2202
 9.99825148197309609976e-01     2168
 9.99825917388341145475e-01     2186
 9.99826686579964318824e-01     2208
 9.99827455772179241045e-01     2174
 9.99828224964986023160e-01     2220
 9.99828994158384554147e-01     2238
 9.99829763352374722984e-01     2216
 9.99830532546956751716e-01     2216
 9.99831301742130529320e-01     2234
 9.99832070937896055796e-01     2250
 9.99832840134253331144e-01     2234
 9.99833609331202355364e-01     2238
 9.99834378528743239478e-01     2244
 9.99835147726875761442e-01     2226
 9.99835916925600143301e-01     2238
 9.99836686124916274032e-01     2262
 9.99837455324824153635e-01     2286
 9.99838224525323782110e-01     2264
 9.99838993726415159458e-01     2276
 9.99839762928098285677e-01     2298
 9.99840532130373271791e-01     2286
 9.99841301333240006777e-01     2292
 9.99842070536698490635e-01     2288
 9.99842839740748723365e-01     2286
 9.99843608945390704967e-01     2332
 9.99844378150624435442e-01     2294
 9.99845147356450025811e-01     2376
 9.99845916562867365052e-01     2406
 9.99846685769876453165e-01     2318
 9.99847454977477290150e-01     2342
 9.99848224185669876007e-01     2346
 9.99848993394454321759e-01     2380
 9.99849762603830405361e-01     2346
 9.99850531813798348857e-01     2358
 9.99851301024358152247e-01     2364
 9.99852070235509593488e-01     2352
 9.99852839447252894622e-01     2412
 9.99853608659587944629e-01     2376
 9.99854377872514743508e-01     2452
 9.99855147086033291259e-01     2408
 9.99855916300143698905e-01     2412
 9.99856685514845744400e-01     2454
 9.99857454730139760812e-01     2432
 9.99858223946025415074e-01     2404
 9.99858993162502818208e-01     2424
 9.99859762379572081237e-01     2442
 9.99860531597233093137e-01     2492
 9.99861300815485964932e-01     2468
 9.99862070034330474577e-01     2434
 9.99862839253766844116e-01     2550
 9.99863608473795073550e-01     2468
 9.99864377694414940834e-01     2484
 9.99865146915626668012e-01     2474
 9.99865916137430144062e-01     2474
 9.99866685359825368984e-01     2518
 9.99867454582812453800e-01     2524
 9.99868223806391287489e-01     2530
 9.99868993030561870050e-01     2556
 9.99869762255324312505e-01     2554
 9.99870531480678503833e-01     2532
 9.99871300706624444032e-01     2618
 9.99872069933162244126e-01     2556
 9.99872839160291793092e-01     2596
 9.99873608388013090931e-01     2542
 9.99874377616326248663e-01     2518
 9.99875146845231155268e-01     2540
 9.99875916074727810745e-01     2558
 9.99876685304816215094e-01     2592
 9.99877454535496479338e-01     2580
 9.99878223766768603475e-01     2600
 9.99878992998632476485e-01     2628
 9.99879762231088098368e-01     2614
 9.99880531464135469122e-01     2688
 9.99881300697774699771e-01     2656
 9.99882069932005679291e-01     2624
 9.99882839166828518707e-01     2652
 9.99883608402243106994e-01     2658
 9.99884377638249444153e-01     2646
 9.99885146874847641207e-01     2654
 9.99885916112037587133e-01     2722
 9.99886685349819392954e-01     2708
 9.99887454588192947647e-01     2696
 9.99888223827158251211e-01     2754
 9.99888993066715414670e-01     2706
 9.99889762306864327002e-01     2696
 9.99890531547605099227e-01     2726
 9.99891300788937620325e-01     2720
 9.99892070030861890295e-01     2730
 9.99892839273378020160e-01     2826
 9.99893608516486009918e-01     2718
 9.99894377760185748549e-01     2880
 9.99895147004477236052e-01     2876
 9.99895916249360583450e-01     3078
 9.99896685494835679719e-01     2822
 9.99897454740902635884e-01     2820
 9.99898223987561340920e-01     2900
 9.99898993234811794828e-01     2904
 9.99899762482654108631e-01     3032
 9.99900531731088282328e-01     2922
 9.99901300980114204897e-01     2932
 9.99902070229731987361e-01     2962
 9.99902839479941518697e-01     3006
 9.99903608730742798905e-01     2882
 9.99904377982135939007e-01     2926
 9.99905147234120939004e-01     2940
 9.99905916486697687873e-01     2988
 9.99906685739866185614e-01     3026
 9.99907454993626543249e-01     3018
 9.99908224247978760779e-01     2992
 9.99908993502922727181e-01     3020
 9.99909762758458553478e-01     3116
 9.99910532014586128646e-01     3026
 9.99911301271305563709e-01     3050
 9.99912070528616747644e-01     3100
 9.99912839786519791474e-01     3060
 9.99913609045014584176e-01     3070
 9.99914378304101236772e-01     3094
 9.99915147563779638240e-01     3118
 9.99915916824049899603e-01     3110
 9.99916686084912020860e-01     3092
 9.99917455346365890989e-01     3086
 9.99918224608411621013e-01     3128
 9.99918993871049099909e-01     3144
 9.99919763134278438699e-01     3290
 9.99920532398099526361e-01     3276
 9.99921301662512473918e-01     3230
 9.99922070927517281369e-01     3242
 9.99922840193113837692e-01     3220
 9.99923609459302253910e-01     3264
 9.99924378726082530022e-01     3280
 9.99925147993454555007e-01     3218
 9.99925917261418328863e-01     3282
 9.99926686529974073636e-01     3350
 9.99927455799121567281e-01     3326
 9.99928225068860809799e-01     3388
 9.99928994339191912211e-01     3392
 9.99929763610114874517e-01     3390
 9.99930532881629585695e-01     3416
 9.99931302153736267790e-01     3482
 9.99932071426434587735e-01     3454
 9.99932840699724878597e-01     3546
 9.99933609973606918331e-01     3492
 9.99934379248080706937e-01     3570
 9.99935148523146466459e-01     3646
 9.99935917798803974854e-01     3592
 9.99936687075053343143e-01     3648
 9.99937456351894460305e-01     3628
 9.99938225629327437360e-01     3630
 9.99938994907352274311e-01     3812
 9.99939764185968860133e-01     3726
 9.99940533465177305850e-01     3726
 9.99941302744977611461e-01     3710
 9.99942072025369776966e-01     3694
 9.99942841306353691344e-01     3866
 9.99943610587929465616e-01     3832
 9.99944379870096988761e-01     3780
 9.99945149152856482822e-01     3834
 9.99945918436207725755e-01     3850
 9.99946687720150828582e-01     3892
 9.99947457004685680282e-01     3872
 9.99948226289812391876e-01     3914
 9.99948995575530963364e-01     3912
 9.99949764861841394747e-01     3926
 9.99950534148743686025e-01     3940
 9.99951303436237726174e-01     3988
 9.99952072724323626218e-01     4024
 9.99952842013001386157e-01     4114
 9.99953611302270894967e-01     4122
 9.99954380592132263672e-01     4136
 9.99955149882585492271e-01     4244
 9.99955919173630580765e-01     4226
 9.99956688465267529153e-01     4274
 9.99957457757496226414e-01     4270
 9.99958227050316783568e-01     4376
 9.99958996343729200618e-01     4570
 9.99959765637733477561e-01     4480
 9.99960534932329614399e-01     4596
 9.99961304227517500109e-01     4628
 9.99962073523297245714e-01     4592
 9.99962842819668851213e-01     4700
 9.99963612116632316607e-01     4688
 9.99964381414187530872e-01     4688
 9.99965150712334716054e-01     4728
 9.99965920011073650109e-01     4750
 9.99966689310404444058e-01     4834
 9.99967458610327097901e-01     4788
 9.99968227910841611639e-01     4850
 9.99968997211947874248e-01     4982
 9.99969766513646107775e-01     5094
 9.99970535815936090174e-01     5150
 9.99971305118817932467e-01     5494
 9.99972074422291634654e-01     5572
 9.99972843726357196736e-01     5380
 9.99973613031014618713e-01     5384
 9.99974382336263900584e-01     5426
 9.99975151642104931327e-01     5732
 9.99975920948537821964e-01     5746
 9.99976690255562683518e-01     5708
 9.99977459563179293944e-01     5742
 9.99978228871387764265e-01     5846
 9.99978998180188094480e-01     5880
 9.99979767489580284590e-01     6104
 9.99980536799564223571e-01     6154
 9.99981306110140133470e-01     6488
 9.99982075421307903262e-01     6710
 9.99982844733067421927e-01     6464
 9.99983614045418911509e-01     6756
 9.99984383358362149963e-01     6810
 9.99985152671897248311e-01     6972
 9.99985921986024206554e-01     7106
 9.99986691300743135713e-01     7292
 9.99987460616053813744e-01     7454
 9.99988229931956351670e-01     7636
 9.99988999248450749491e-01     8090
 9.99989768565537007206e-01     8158
 9.99990537883215013792e-01     8510
 9.99991307201484991296e-01     8914
 9.99992076520346828694e-01     9376
 9.99992845839800525987e-01    10020
 9.99993615159846083174e-01    10534
 9.99994384480483389233e-01    10916
 9.99995153801712666208e-01    11542
 9.99995923123533803079e-01    12514
 9.99996692445946799843e-01    14188
 9.99997461768951545480e-01    15918
 9.99998231092548262033e-01    18752
 9.99999000416736838481e-01    24100
 9.99999769741517163801e-01    46698
 9.99999770510842322935e-01    46890
 9.99999771280167371046e-01    46662
 9.99999772049492419157e-01    46910
 9.99999772818817467268e-01    47550
 9.99999773588142626402e-01    46864
 9.99999774357467674513e-01    46568
 9.99999775126792722624e-01    47824
 9.99999775896117881757e-01    47040
 9.99999776665442929868e-01    46414
 9.99999777434767977979e-01    46250
 9.99999778204093137113e-01    46928
 9.99999778973418185224e-01    48040
 9.99999779742743233335e-01    48066
 9.99999780512068281446e-01    48246
 9.99999781281393440580e-01    47460
 9.99999782050718488691e-01    47474
 9.99999782820043647824e-01    48204
 9.99999783589368695935e-01    48998
 9.99999784358693744046e-01    49828
 9.99999785128018903180e-01    52860
 9.99999785897343951291e-01    50756
 9.99999786666668999402e-01    48668
 9.99999787435994158535e-01    48488
 9.99999788205319206646e-01    49286
 9.99999788974644254758e-01    48904
 9.99999789743969413891e-01    49776
 9.99999790513294462002e-01    50490
 9.99999791282619621136e-01    49918
 9.99999792051944669247e-01    50100
 9.99999792821269717358e-01    49338
 9.99999793590594876491e-01    48802
 9.99999794359919924602e-01    49182
 9.99999795129245083736e-01    51664
 9.99999795898570131847e-01    50130
 9.99999796667895290980e-01    49976
 9.99999797437220339091e-01    50672
 9.99999798206545387202e-01    50568
 9.99999798975870546336e-01    49540
 9.99999799745195594447e-01    52172
 9.99999800514520753580e-01    51258
 9.99999801283845801692e-01    50994
 9.99999802053170960825e-01    51050
 9.99999802822496008936e-01    51130
 9.99999803591821168069e-01    51082
 9.99999804361146216181e-01    50676
 9.99999805130471375314e-01    52524
 9.99999805899796423425e-01    51646
 9.99999806669121582559e-01    51992
 9.99999807438446630670e-01    52744
 9.99999808207771789803e-01    51326
 9.99999808977096837914e-01    53530
 9.99999809746421997048e-01    51670
 9.99999810515747045159e-01    52504
 9.99999811285072204292e-01    52050
 9.99999812054397252403e-01    52046
 9.99999812823722411537e-01    51536
 9.99999813593047570670e-01    51820
 9.99999814362372618781e-01    52530
 9.99999815131697777915e-01    52314
 9.99999815901022826026e-01    52180
 9.99999816670347985159e-01    52562
 9.99999817439673033270e-01    52018
 9.99999818208998192404e-01    53604
 9.99999818978323351537e-01    53648
 9.99999819747648399648e-01    52080
 9.99999820516973558782e-01    53086
 9.99999821286298606893e-01    53078
 9.99999822055623766026e-01    52542
 9.99999822824948925160e-01    53138
 9.99999823594273973271e-01    54090
 9.99999824363599132404e-01    53352
 9.99999825132924291538e-01    53034
 9.99999825902249339649e-01    54180
 9.99999826671574498782e-01    53812
 9.99999827440899546893e-01    53198
 9.99999828210224706027e-01    53406
 9.99999828979549865160e-01    53348
 9.99999829748874913271e-01    54018
 9.99999830518200072405e-01    54856
 9.99999831287525231538e-01    53902
 9.99999832056850279649e-01    54856
 9.99999832826175438782e-01    56218
 9.99999833595500597916e-01    55292
 9.99999834364825757049e-01    54900
 9.99999835134150805160e-01    54880
 9.99999835903475964294e-01    55328
 9.99999836672801123427e-01    57410
 9.99999837442126171538e-01    55234
 9.99999838211451330672e-01    55702
 9.99999838980776489805e-01    55462
 9.99999839750101648939e-01    56832
 9.99999840519426697050e-01    57264
 9.99999841288751856183e-01    56814
 9.99999842058077015317e-01    56706
 9.99999842827402174450e-01    56820
 9.99999843596727222561e-01    57166
 9.99999844366052381694e-01    58980
 9.99999845135377540828e-01    57348
 9.99999845904702699961e-01    57518
 9.99999846674027748072e-01    57392
 9.99999847443352907206e-01    57216
 9.99999848212678066339e-01    59352
 9.99999848982003225473e-01    57874
 9.99999849751328384606e-01    57328
 9.99999850520653432717e-01    57478
 9.99999851289978591851e-01    57174
 9.99999852059303750984e-01    57382
 9.99999852828628910117e-01    58832
 9.99999853597954069251e-01    57616
 9.99999854367279228384e-01    58072
 9.99999855136604276495e-01    57856
 9.99999855905929435629e-01    58790
 9.99999856675254594762e-01    57942
 9.99999857444579753896e-01    59086
 9.99999858213904913029e-01    58818
 9.99999858983230072162e-01    59976
 9.99999859752555231296e-01    58716
 9.99999860521880390429e-01    59904
 9.99999861291205438540e-01    59086
 9.99999862060530597674e-01    58666
 9.99999862829855756807e-01    58864
 9.99999863599180915941e-01    59956
 9.99999864368506075074e-01    60682
 9.99999865137831234208e-01    60976
 9.99999865907156393341e-01    59790
 9.99999866676481552474e-01    60644
 9.99999867445806711608e-01    60286
 9.99999868215131870741e-01    60050
 9.99999868984457029875e-01    61748
 9.99999869753782189008e-01    61030
 9.99999870523107237119e-01    61188
 9.99999871292432396253e-01    61834
 9.99999872061757555386e-01    61900
 9.99999872831082714519e-01    60976
 9.99999873600407873653e-01    61246
 9.99999874369733032786e-01    62022
 9.99999875139058191920e-01    61736
 9.99999875908383351053e-01    62130
 9.99999876677708510186e-01    62378
 9.99999877447033669320e-01    62476
 9.99999878216358828453e-01    62510
 9.99999878985683987587e-01    62410
 9.99999879755009146720e-01    65752
 9.99999880524334305854e-01    67114
 9.99999881293659464987e-01    64132
 9.99999882062984624120e-01    65664
 9.99999882832309783254e-01    65478
 9.99999883601634942387e-01    67324
 9.99999884370960101521e-01    65506
 9.99999885140285371676e-01    69376
 9.99999885909610530810e-01    65498
 9.99999886678935689943e-01    65642
 9.99999887448260849077e-01    65386
 9.99999888217586008210e-01    65580
 9.99999888986911167343e-01    66514
 9.99999889756236326477e-01    66678
 9.99999890525561485610e-01    66712
 9.99999891294886644744e-01    66182
 9.99999892064211803877e-01    68560
 9.99999892833536963010e-01    66964
 9.99999893602862122144e-01    66658
 9.99999894372187392300e-01    68582
 9.99999895141512551433e-01    67954
 9.99999895910837710566e-01    68022
 9.99999896680162869700e-01    69754
 9.99999897449488028833e-01    67520
 9.99999898218813187967e-01    68402
 9.99999898988138347100e-01    67362
 9.99999899757463617256e-01    68252
 9.99999900526788776389e-01    68124
 9.99999901296113935523e-01    69706
 9.99999902065439094656e-01    68550
 9.99999902834764253790e-01    68362
 9.99999903604089412923e-01    69418
 9.99999904373414683079e-01    69416
 9.99999905142739842212e-01    69328
 9.99999905912065001345e-01    70208
 9.99999906681390160479e-01    70712
 9.99999907450715319612e-01    70854
 9.99999908220040589768e-01    70832
 9.99999908989365748901e-01    71004
 9.99999909758690908035e-01    71116
 9.99999910528016067168e-01    71228
 9.99999911297341226302e-01    71156
 9.99999912066666496457e-01    72360
 9.99999912835991655591e-01    72292
 9.99999913605316814724e-01    73792
 9.99999914374641973858e-01    73054
 9.99999915143967244013e-01    73166
 9.99999915913292403147e-01    73612
 9.99999916682617562280e-01    74330
 9.99999917451942721414e-01    74676
 9.99999918221267991569e-01    75226
 9.99999918990593150703e-01    77636
 9.99999919759918309836e-01    76558
 9.99999920529243579992e-01    77616
 9.99999921298568739125e-01    78378
 9.99999922067893898259e-01    76928
 9.99999922837219168414e-01    78314
 9.99999923606544327548e-01    79198
 9.99999924375869486681e-01    79646
 9.99999925145194756837e-01    77612
 9.99999925914519915970e-01    77162
 9.99999926683845075104e-01    79224
 9.99999927453170345260e-01    78766
 9.99999928222495504393e-01    81170
 9.99999928991820663526e-01    83378
 9.99999929761145933682e-01    82338
 9.99999930530471092816e-01    83886
 9.99999931299796251949e-01    83280
 9.99999932069121522105e-01    83732
 9.99999932838446681238e-01    84746
 9.99999933607771840371e-01    81982
 9.99999934377097110527e-01    86974
 9.99999935146422269661e-01    87110
 9.99999935915747539816e-01    87716
 9.99999936685072698950e-01    88208
 9.99999937454397969105e-01    88962
 9.99999938223723128239e-01    89194
 9.99999938993048287372e-01    89506
 9.99999939762373557528e-01    87752
 9.99999940531698716661e-01   131072
 9.99999941301023986817e-01    88986
 9.99999942070349145951e-01    92214
 9.99999942839674416106e-01    95222
 9.99999943608999575240e-01    94896
 9.99999944378324734373e-01    90682
 9.99999945147650004529e-01    93978
 9.99999945916975163662e-01    96758
 9.99999946686300433818e-01    94360
 9.99999947455625592951e-01    95140
 9.99999948224950863107e-01   131072
 9.99999948994276022241e-01   131072
 9.99999949763601292396e-01    95592
 9.99999950532926451530e-01    94136
 9.99999951302251721685e-01    96450
 9.99999952071576880819e-01    97402
 9.99999952840902150975e-01    97482
 9.99999953610227310108e-01    98048
 9.99999954379552580264e-01   131072
 9.99999955148877739397e-01   131072
 9.99999955918203009553e-01   131072
 9.99999956687528279708e-01   131072
 9.99999957456853438842e-01   131072
 9.99999958226178708998e-01   131072
 9.99999958995503868131e-01   131072
 9.99999959764829138287e-01   131072
 9.99999960534154297420e-01   131072
 9.99999961303479567576e-01   131072
 9.99999962072804837732e-01   131072
 9.99999962842129996865e-01   131072
 9.99999963611455267021e-01   131072
 9.99999964380780426154e-01   131072
 9.99999965150105696310e-01   131072
 9.99999965919430966466e-01   131072
 9.99999966688756125599e-01   131072
 9.99999967458081395755e-01   131072
 9.99999968227406554888e-01   131072
 9.99999968996731825044e-01   131072
 9.99999969766057095200e-01   131072
 9.99999970535382254333e-01   131072
 9.99999971304707524489e-01   131072
 9.99999972074032794644e-01   131072
 9.99999972843357953778e-01   131072
 9.99999973612683223934e-01   131072
 9.99999974382008494089e-01   131072
 9.99999975151333653223e-01   131072
 9.99999975920658923378e-01   131072
 9.99999976689984193534e-01   131072
 9.99999977459309352668e-01   131072
 9.99999978228634622823e-01   131072
 9.99999978997959892979e-01   131072
 9.99999979767285052112e-01   131072
 9.99999980536610322268e-01   131072
 9.99999981305935592424e-01   131072
 9.99999982075260862580e-01   131072
 9.99999982844586021713e-01   131072
 9.99999983613911291869e-01   131072
 9.99999984383236562024e-01   131072
 9.99999985152561832180e-01   131072
 9.99999985921886991314e-01   131072
 9.99999986691212261469e-01   131072
 9.99999987460537531625e-01   131072
 9.99999988229862801781e-01   131072
 9.99999988999187960914e-01   131072
 9.99999989768513231070e-01   131072
 9.99999990537838501226e-01   131072
 9.99999991307163771381e-01   131072
 9.99999992076489041537e-01   131072
 9.99999992845814200670e-01   131072
 9.99999993615139470826e-01   131072
 9.99999994384464740982e-01   131072
 9.99999995153790011138e-01   131072
 9.99999995923115281293e-01   131072
 9.99999996692440440427e-01   131072
 9.99999997461765710582e-01   131072
 9.99999998231090980738e-01   131072
 9.99999999000416250894e-01   131072
 9.99999999769741521050e-01   131072];



